import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  DatePicker,
  TimePicker,
  Form,
  Row,
  Col,
  Statistic,
  Tooltip,
  Avatar,
  Badge,
  Calendar
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  EditOutlined,
  DeleteOutlined,
  PlusOutlined,
  ReloadOutlined,
  UserOutlined,
  CalendarOutlined,
  ClockCircleOutlined,
  PhoneOutlined,
  VideoCameraOutlined,
  CheckOutlined,
  CloseOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';
import dayjs from 'dayjs';

const { Title } = Typography;
const { Option } = Select;
const { RangePicker } = DatePicker;

interface Appointment {
  id: string;
  clientName: string;
  clientPhone: string;
  clientEmail: string;
  appointmentDate: string;
  appointmentTime: string;
  duration: number; // 分钟
  serviceType: 'voice' | 'video' | 'document';
  sourceLanguage: string;
  targetLanguage: string;
  translator?: string;
  status: 'pending' | 'confirmed' | 'in-progress' | 'completed' | 'cancelled';
  notes?: string;
  cost: number;
  createdTime: string;
}

const AppointmentList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [appointments, setAppointments] = useState<Appointment[]>([]);
  const [filteredAppointments, setFilteredAppointments] = useState<Appointment[]>([]);
  const [searchText, setSearchText] = useState('');
  const [statusFilter, setStatusFilter] = useState<string>('all');
  const [serviceTypeFilter, setServiceTypeFilter] = useState<string>('all');
  const [dateRange, setDateRange] = useState<[dayjs.Dayjs, dayjs.Dayjs] | null>(null);
  const [modalVisible, setModalVisible] = useState(false);
  const [editingAppointment, setEditingAppointment] = useState<Appointment | null>(null);
  const [calendarVisible, setCalendarVisible] = useState(false);
  const [form] = Form.useForm();

  // 模拟数据
  const mockAppointments: Appointment[] = [
    {
      id: '1',
      clientName: '张先生',
      clientPhone: '13800138001',
      clientEmail: 'zhang@example.com',
      appointmentDate: '2024-01-16',
      appointmentTime: '10:00',
      duration: 60,
      serviceType: 'video',
      sourceLanguage: '中文',
      targetLanguage: '英文',
      translator: '王译员',
      status: 'confirmed',
      notes: '商务会议翻译',
      cost: 300,
      createdTime: '2024-01-15 14:30:00'
    },
    {
      id: '2',
      clientName: '李女士',
      clientPhone: '13800138002',
      clientEmail: 'li@example.com',
      appointmentDate: '2024-01-16',
      appointmentTime: '14:30',
      duration: 90,
      serviceType: 'voice',
      sourceLanguage: '英文',
      targetLanguage: '中文',
      translator: '李译员',
      status: 'in-progress',
      notes: '医疗咨询翻译',
      cost: 450,
      createdTime: '2024-01-15 14:25:00'
    },
    {
      id: '3',
      clientName: '王总',
      clientPhone: '13800138003',
      clientEmail: 'wang@example.com',
      appointmentDate: '2024-01-17',
      appointmentTime: '09:00',
      duration: 120,
      serviceType: 'video',
      sourceLanguage: '中文',
      targetLanguage: '日文',
      translator: '张译员',
      status: 'pending',
      notes: '技术交流会议',
      cost: 600,
      createdTime: '2024-01-15 14:20:00'
    },
    {
      id: '4',
      clientName: '陈先生',
      clientPhone: '13800138004',
      clientEmail: 'chen@example.com',
      appointmentDate: '2024-01-15',
      appointmentTime: '16:00',
      duration: 45,
      serviceType: 'document',
      sourceLanguage: '德文',
      targetLanguage: '中文',
      translator: '赵译员',
      status: 'completed',
      notes: '合同翻译讨论',
      cost: 225,
      createdTime: '2024-01-15 14:15:00'
    },
    {
      id: '5',
      clientName: '刘女士',
      clientPhone: '13800138005',
      clientEmail: 'liu@example.com',
      appointmentDate: '2024-01-18',
      appointmentTime: '11:00',
      duration: 30,
      serviceType: 'voice',
      sourceLanguage: '法文',
      targetLanguage: '中文',
      status: 'cancelled',
      notes: '客户临时取消',
      cost: 0,
      createdTime: '2024-01-15 14:10:00'
    }
  ];

  const fetchAppointments = async () => {
    setLoading(true);
    try {
      // 模拟API调用
      await new Promise(resolve => setTimeout(resolve, 1000));
      setAppointments(mockAppointments);
      setFilteredAppointments(mockAppointments);
      message.success('预约列表加载成功');
    } catch (error) {
      message.error('加载预约列表失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchAppointments();
  }, []);

  useEffect(() => {
    let filtered = appointments;

    // 搜索过滤
    if (searchText) {
      filtered = filtered.filter(apt => 
        apt.clientName.toLowerCase().includes(searchText.toLowerCase()) ||
        apt.clientPhone.includes(searchText) ||
        apt.sourceLanguage.includes(searchText) ||
        apt.targetLanguage.includes(searchText) ||
        (apt.translator && apt.translator.includes(searchText))
      );
    }

    // 状态过滤
    if (statusFilter !== 'all') {
      filtered = filtered.filter(apt => apt.status === statusFilter);
    }

    // 服务类型过滤
    if (serviceTypeFilter !== 'all') {
      filtered = filtered.filter(apt => apt.serviceType === serviceTypeFilter);
    }

    // 日期范围过滤
    if (dateRange) {
      const [startDate, endDate] = dateRange;
      filtered = filtered.filter(apt => {
        const aptDate = dayjs(apt.appointmentDate);
        return aptDate.isAfter(startDate.subtract(1, 'day')) && 
               aptDate.isBefore(endDate.add(1, 'day'));
      });
    }

    setFilteredAppointments(filtered);
  }, [appointments, searchText, statusFilter, serviceTypeFilter, dateRange]);

  const getStatusTag = (status: string) => {
    const statusConfig = {
      pending: { color: 'orange', text: '待确认' },
      confirmed: { color: 'blue', text: '已确认' },
      'in-progress': { color: 'green', text: '进行中' },
      completed: { color: 'cyan', text: '已完成' },
      cancelled: { color: 'red', text: '已取消' }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const getServiceTypeTag = (type: string) => {
    const typeConfig = {
      voice: { color: 'blue', text: '语音翻译', icon: <PhoneOutlined /> },
      video: { color: 'green', text: '视频翻译', icon: <VideoCameraOutlined /> },
      document: { color: 'purple', text: '文档讨论', icon: <EyeOutlined /> }
    };
    const config = typeConfig[type as keyof typeof typeConfig];
    return (
      <Tag color={config.color} icon={config.icon}>
        {config.text}
      </Tag>
    );
  };

  const handleStatusChange = (appointmentId: string, newStatus: string) => {
    const updatedAppointments = appointments.map(apt => 
      apt.id === appointmentId ? { ...apt, status: newStatus as Appointment['status'] } : apt
    );
    setAppointments(updatedAppointments);
    message.success('状态更新成功');
  };

  const handleEdit = (appointment: Appointment) => {
    setEditingAppointment(appointment);
    form.setFieldsValue({
      ...appointment,
      appointmentDate: dayjs(appointment.appointmentDate),
      appointmentTime: dayjs(appointment.appointmentTime, 'HH:mm')
    });
    setModalVisible(true);
  };

  const handleDelete = (appointment: Appointment) => {
    Modal.confirm({
      title: '确认删除',
      content: `确定要删除 ${appointment.clientName} 的预约吗？`,
      onOk: () => {
        const newAppointments = appointments.filter(apt => apt.id !== appointment.id);
        setAppointments(newAppointments);
        message.success('预约删除成功');
      }
    });
  };

  const handleSave = async (values: any) => {
    try {
      const appointmentData = {
        ...values,
        appointmentDate: values.appointmentDate.format('YYYY-MM-DD'),
        appointmentTime: values.appointmentTime.format('HH:mm'),
      };

      if (editingAppointment) {
        // 更新预约
        const updatedAppointments = appointments.map(apt => 
          apt.id === editingAppointment.id ? { ...apt, ...appointmentData } : apt
        );
        setAppointments(updatedAppointments);
        message.success('预约更新成功');
      } else {
        // 新增预约
        const newAppointment: Appointment = {
          id: Date.now().toString(),
          ...appointmentData,
          status: 'pending',
          createdTime: new Date().toLocaleString()
        };
        setAppointments([...appointments, newAppointment]);
        message.success('预约创建成功');
      }

      setModalVisible(false);
      setEditingAppointment(null);
      form.resetFields();
    } catch (error) {
      message.error('保存失败');
    }
  };

  const columns: ColumnsType<Appointment> = [
    {
      title: '客户信息',
      key: 'client',
      width: 200,
      render: (_, record) => (
        <div>
          <div style={{ display: 'flex', alignItems: 'center', marginBottom: 4 }}>
            <Avatar size="small" icon={<UserOutlined />} />
            <span style={{ marginLeft: 8, fontWeight: 'bold' }}>{record.clientName}</span>
          </div>
          <div style={{ fontSize: '12px', color: '#666' }}>
            {record.clientPhone}
          </div>
        </div>
      )
    },
    {
      title: '预约时间',
      key: 'datetime',
      width: 150,
      render: (_, record) => (
        <div>
          <div style={{ display: 'flex', alignItems: 'center', marginBottom: 4 }}>
            <CalendarOutlined style={{ marginRight: 4 }} />
            {record.appointmentDate}
          </div>
          <div style={{ display: 'flex', alignItems: 'center' }}>
            <ClockCircleOutlined style={{ marginRight: 4 }} />
            {record.appointmentTime} ({record.duration}分钟)
          </div>
        </div>
      )
    },
    {
      title: '服务类型',
      dataIndex: 'serviceType',
      key: 'serviceType',
      width: 120,
      render: getServiceTypeTag
    },
    {
      title: '语言对',
      key: 'languages',
      width: 150,
      render: (_, record) => (
        <div>
          <Tag color="blue">{record.sourceLanguage}</Tag>
          <span style={{ margin: '0 4px' }}>→</span>
          <Tag color="green">{record.targetLanguage}</Tag>
        </div>
      )
    },
    {
      title: '译员',
      dataIndex: 'translator',
      key: 'translator',
      width: 100,
      render: (text) => text || '-'
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: getStatusTag
    },
    {
      title: '费用(元)',
      dataIndex: 'cost',
      key: 'cost',
      width: 100,
      render: (cost) => cost > 0 ? `¥${cost.toFixed(2)}` : '-'
    },
    {
      title: '操作',
      key: 'action',
      width: 200,
      render: (_, record) => (
        <Space>
          <Tooltip title="查看详情">
            <Button
              type="primary"
              size="small"
              icon={<EyeOutlined />}
            />
          </Tooltip>
          <Tooltip title="编辑">
            <Button
              size="small"
              icon={<EditOutlined />}
              onClick={() => handleEdit(record)}
            />
          </Tooltip>
          {record.status === 'pending' && (
            <Tooltip title="确认">
              <Button
                size="small"
                icon={<CheckOutlined />}
                style={{ color: 'green' }}
                onClick={() => handleStatusChange(record.id, 'confirmed')}
              />
            </Tooltip>
          )}
          {record.status !== 'cancelled' && record.status !== 'completed' && (
            <Tooltip title="取消">
              <Button
                size="small"
                icon={<CloseOutlined />}
                danger
                onClick={() => handleStatusChange(record.id, 'cancelled')}
              />
            </Tooltip>
          )}
          <Tooltip title="删除">
            <Button
              danger
              size="small"
              icon={<DeleteOutlined />}
              onClick={() => handleDelete(record)}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  // 统计数据
  const stats = {
    total: filteredAppointments.length,
    pending: filteredAppointments.filter(a => a.status === 'pending').length,
    confirmed: filteredAppointments.filter(a => a.status === 'confirmed').length,
    inProgress: filteredAppointments.filter(a => a.status === 'in-progress').length,
    completed: filteredAppointments.filter(a => a.status === 'completed').length,
    totalRevenue: filteredAppointments.filter(a => a.status === 'completed').reduce((sum, a) => sum + a.cost, 0)
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>预约管理</Title>

      {/* 统计卡片 */}
      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={4}>
          <Card>
            <Statistic
              title="总预约数"
              value={stats.total}
              prefix={<CalendarOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="待确认"
              value={stats.pending}
              valueStyle={{ color: '#faad14' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="已确认"
              value={stats.confirmed}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="进行中"
              value={stats.inProgress}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="已完成"
              value={stats.completed}
              valueStyle={{ color: '#13c2c2' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalRevenue}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        {/* 搜索和筛选 */}
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={6}>
            <Input
              placeholder="搜索客户、电话、语言..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={4}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="pending">待确认</Option>
              <Option value="confirmed">已确认</Option>
              <Option value="in-progress">进行中</Option>
              <Option value="completed">已完成</Option>
              <Option value="cancelled">已取消</Option>
            </Select>
          </Col>
          <Col span={4}>
            <Select
              value={serviceTypeFilter}
              onChange={setServiceTypeFilter}
              style={{ width: '100%' }}
              placeholder="服务类型"
            >
              <Option value="all">全部类型</Option>
              <Option value="voice">语音翻译</Option>
              <Option value="video">视频翻译</Option>
              <Option value="document">文档讨论</Option>
            </Select>
          </Col>
          <Col span={6}>
            <RangePicker
              style={{ width: '100%' }}
              value={dateRange}
              onChange={(dates) => setDateRange(dates as [dayjs.Dayjs, dayjs.Dayjs] | null)}
              placeholder={['开始日期', '结束日期']}
            />
          </Col>
          <Col span={4}>
            <Space>
              <Button
                type="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setEditingAppointment(null);
                  form.resetFields();
                  setModalVisible(true);
                }}
              >
                新增预约
              </Button>
              <Button
                icon={<ReloadOutlined />}
                onClick={fetchAppointments}
                loading={loading}
              />
            </Space>
          </Col>
        </Row>

        {/* 预约列表表格 */}
        <Table
          columns={columns}
          dataSource={filteredAppointments}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredAppointments.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>

      {/* 预约编辑弹窗 */}
      <Modal
        title={editingAppointment ? '编辑预约' : '新增预约'}
        open={modalVisible}
        onCancel={() => {
          setModalVisible(false);
          setEditingAppointment(null);
          form.resetFields();
        }}
        onOk={() => form.submit()}
        width={800}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={handleSave}
        >
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="clientName"
                label="客户姓名"
                rules={[{ required: true, message: '请输入客户姓名' }]}
              >
                <Input />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="clientPhone"
                label="联系电话"
                rules={[{ required: true, message: '请输入联系电话' }]}
              >
                <Input />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="appointmentDate"
                label="预约日期"
                rules={[{ required: true, message: '请选择预约日期' }]}
              >
                <DatePicker style={{ width: '100%' }} />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="appointmentTime"
                label="预约时间"
                rules={[{ required: true, message: '请选择预约时间' }]}
              >
                <TimePicker format="HH:mm" style={{ width: '100%' }} />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={8}>
              <Form.Item
                name="duration"
                label="时长(分钟)"
                rules={[{ required: true, message: '请输入时长' }]}
              >
                <Input type="number" />
              </Form.Item>
            </Col>
            <Col span={8}>
              <Form.Item
                name="serviceType"
                label="服务类型"
                rules={[{ required: true, message: '请选择服务类型' }]}
              >
                <Select>
                  <Option value="voice">语音翻译</Option>
                  <Option value="video">视频翻译</Option>
                  <Option value="document">文档讨论</Option>
                </Select>
              </Form.Item>
            </Col>
            <Col span={8}>
              <Form.Item
                name="cost"
                label="费用(元)"
                rules={[{ required: true, message: '请输入费用' }]}
              >
                <Input type="number" />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="sourceLanguage"
                label="源语言"
                rules={[{ required: true, message: '请选择源语言' }]}
              >
                <Select>
                  <Option value="中文">中文</Option>
                  <Option value="英文">英文</Option>
                  <Option value="日文">日文</Option>
                  <Option value="韩文">韩文</Option>
                  <Option value="法文">法文</Option>
                  <Option value="德文">德文</Option>
                </Select>
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="targetLanguage"
                label="目标语言"
                rules={[{ required: true, message: '请选择目标语言' }]}
              >
                <Select>
                  <Option value="中文">中文</Option>
                  <Option value="英文">英文</Option>
                  <Option value="日文">日文</Option>
                  <Option value="韩文">韩文</Option>
                  <Option value="法文">法文</Option>
                  <Option value="德文">德文</Option>
                </Select>
              </Form.Item>
            </Col>
          </Row>
          <Form.Item
            name="notes"
            label="备注"
          >
            <Input.TextArea rows={3} />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default AppointmentList; 