import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  DatePicker,
  Row,
  Col,
  Statistic
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  ReloadOutlined,
  PhoneOutlined,
  ClockCircleOutlined,
  UserOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';

const { Title } = Typography;
const { RangePicker } = DatePicker;
const { Option } = Select;

interface CallRecord {
  id: string;
  caller: string;
  callee: string;
  startTime: string;
  endTime: string;
  duration: string;
  status: 'completed' | 'ongoing' | 'failed' | 'missed';
  type: 'voice' | 'video';
  language: string;
  translator?: string;
  quality: number;
  cost: number;
}

const CallList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [calls, setCalls] = useState<CallRecord[]>([]);
  const [filteredCalls, setFilteredCalls] = useState<CallRecord[]>([]);
  const [searchText, setSearchText] = useState('');
  const [statusFilter, setStatusFilter] = useState<string>('all');
  const [typeFilter, setTypeFilter] = useState<string>('all');
  const [selectedCall, setSelectedCall] = useState<CallRecord | null>(null);
  const [detailModalVisible, setDetailModalVisible] = useState(false);

  // 模拟数据
  const mockCalls: CallRecord[] = [
    {
      id: '1',
      caller: '张三 (+86 138****1234)',
      callee: '李四 (+1 555****5678)',
      startTime: '2024-01-15 14:30:00',
      endTime: '2024-01-15 14:45:30',
      duration: '15:30',
      status: 'completed',
      type: 'video',
      language: '中文-英文',
      translator: '王译员',
      quality: 4.8,
      cost: 45.50
    },
    {
      id: '2',
      caller: '李四 (+1 555****5678)',
      callee: '王五 (+86 139****5678)',
      startTime: '2024-01-15 14:25:00',
      endTime: '',
      duration: '08:45',
      status: 'ongoing',
      type: 'voice',
      language: '英文-中文',
      translator: '赵译员',
      quality: 0,
      cost: 0
    },
    {
      id: '3',
      caller: '王五 (+86 139****5678)',
      callee: '赵六 (+81 90****1234)',
      startTime: '2024-01-15 14:20:00',
      endTime: '2024-01-15 14:42:10',
      duration: '22:10',
      status: 'completed',
      type: 'video',
      language: '中文-日文',
      translator: '孙译员',
      quality: 4.9,
      cost: 66.30
    },
    {
      id: '4',
      caller: '赵六 (+81 90****1234)',
      callee: '孙七 (+86 137****9876)',
      startTime: '2024-01-15 14:15:00',
      endTime: '2024-01-15 14:20:15',
      duration: '05:15',
      status: 'failed',
      type: 'voice',
      language: '日文-中文',
      translator: '',
      quality: 0,
      cost: 0
    },
    {
      id: '5',
      caller: '孙七 (+86 137****9876)',
      callee: '周八 (+49 30****5678)',
      startTime: '2024-01-15 14:10:00',
      endTime: '',
      duration: '00:00',
      status: 'missed',
      type: 'voice',
      language: '中文-德文',
      translator: '',
      quality: 0,
      cost: 0
    }
  ];

  const fetchCalls = async () => {
    setLoading(true);
    try {
      // 模拟API调用
      await new Promise(resolve => setTimeout(resolve, 1000));
      setCalls(mockCalls);
      setFilteredCalls(mockCalls);
      message.success('通话记录加载成功');
    } catch (error) {
      message.error('加载通话记录失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchCalls();
  }, []);

  useEffect(() => {
    let filtered = calls;

    // 搜索过滤
    if (searchText) {
      filtered = filtered.filter(call => 
        call.caller.toLowerCase().includes(searchText.toLowerCase()) ||
        call.callee.toLowerCase().includes(searchText.toLowerCase()) ||
        call.language.includes(searchText) ||
        (call.translator && call.translator.includes(searchText))
      );
    }

    // 状态过滤
    if (statusFilter !== 'all') {
      filtered = filtered.filter(call => call.status === statusFilter);
    }

    // 类型过滤
    if (typeFilter !== 'all') {
      filtered = filtered.filter(call => call.type === typeFilter);
    }

    setFilteredCalls(filtered);
  }, [calls, searchText, statusFilter, typeFilter]);

  const getStatusTag = (status: string) => {
    const statusConfig = {
      completed: { color: 'green', text: '已完成' },
      ongoing: { color: 'blue', text: '进行中' },
      failed: { color: 'red', text: '失败' },
      missed: { color: 'orange', text: '未接听' }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const getTypeTag = (type: string) => {
    return type === 'video' ? 
      <Tag color="purple">视频通话</Tag> : 
      <Tag color="cyan">语音通话</Tag>;
  };

  const columns: ColumnsType<CallRecord> = [
    {
      title: '通话ID',
      dataIndex: 'id',
      key: 'id',
      width: 80,
    },
    {
      title: '呼叫方',
      dataIndex: 'caller',
      key: 'caller',
      width: 200,
      render: (text) => (
        <div>
          <UserOutlined style={{ marginRight: 8 }} />
          {text}
        </div>
      )
    },
    {
      title: '接听方',
      dataIndex: 'callee',
      key: 'callee',
      width: 200,
      render: (text) => (
        <div>
          <UserOutlined style={{ marginRight: 8 }} />
          {text}
        </div>
      )
    },
    {
      title: '开始时间',
      dataIndex: 'startTime',
      key: 'startTime',
      width: 160,
    },
    {
      title: '通话时长',
      dataIndex: 'duration',
      key: 'duration',
      width: 100,
      render: (text) => (
        <div>
          <ClockCircleOutlined style={{ marginRight: 4 }} />
          {text}
        </div>
      )
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: getStatusTag
    },
    {
      title: '类型',
      dataIndex: 'type',
      key: 'type',
      width: 100,
      render: getTypeTag
    },
    {
      title: '语言',
      dataIndex: 'language',
      key: 'language',
      width: 120,
    },
    {
      title: '译员',
      dataIndex: 'translator',
      key: 'translator',
      width: 100,
      render: (text) => text || '-'
    },
    {
      title: '评分',
      dataIndex: 'quality',
      key: 'quality',
      width: 80,
      render: (score) => score > 0 ? `${score}/5` : '-'
    },
    {
      title: '费用(元)',
      dataIndex: 'cost',
      key: 'cost',
      width: 100,
      render: (cost) => cost > 0 ? `¥${cost.toFixed(2)}` : '-'
    },
    {
      title: '操作',
      key: 'action',
      width: 100,
      render: (_, record) => (
        <Button
          type="primary"
          size="small"
          icon={<EyeOutlined />}
          onClick={() => {
            setSelectedCall(record);
            setDetailModalVisible(true);
          }}
        >
          详情
        </Button>
      ),
    },
  ];

  // 统计数据
  const stats = {
    total: filteredCalls.length,
    completed: filteredCalls.filter(c => c.status === 'completed').length,
    ongoing: filteredCalls.filter(c => c.status === 'ongoing').length,
    failed: filteredCalls.filter(c => c.status === 'failed').length,
    totalRevenue: filteredCalls.reduce((sum, c) => sum + c.cost, 0)
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>通话管理</Title>

      {/* 统计卡片 */}
      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总通话数"
              value={stats.total}
              prefix={<PhoneOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="已完成"
              value={stats.completed}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="进行中"
              value={stats.ongoing}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalRevenue}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        {/* 搜索和筛选 */}
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={6}>
            <Input
              placeholder="搜索呼叫方、接听方、译员..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={4}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="completed">已完成</Option>
              <Option value="ongoing">进行中</Option>
              <Option value="failed">失败</Option>
              <Option value="missed">未接听</Option>
            </Select>
          </Col>
          <Col span={4}>
            <Select
              value={typeFilter}
              onChange={setTypeFilter}
              style={{ width: '100%' }}
              placeholder="类型筛选"
            >
              <Option value="all">全部类型</Option>
              <Option value="voice">语音通话</Option>
              <Option value="video">视频通话</Option>
            </Select>
          </Col>
          <Col span={6}>
            <RangePicker style={{ width: '100%' }} />
          </Col>
          <Col span={4}>
            <Space>
              <Button
                type="primary"
                icon={<ReloadOutlined />}
                onClick={fetchCalls}
                loading={loading}
              >
                刷新
              </Button>
            </Space>
          </Col>
        </Row>

        {/* 通话记录表格 */}
        <Table
          columns={columns}
          dataSource={filteredCalls}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredCalls.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>

      {/* 详情弹窗 */}
      <Modal
        title="通话详情"
        open={detailModalVisible}
        onCancel={() => setDetailModalVisible(false)}
        footer={[
          <Button key="close" onClick={() => setDetailModalVisible(false)}>
            关闭
          </Button>
        ]}
        width={600}
      >
        {selectedCall && (
          <div>
            <Row gutter={16}>
              <Col span={12}>
                <p><strong>通话ID:</strong> {selectedCall.id}</p>
                <p><strong>呼叫方:</strong> {selectedCall.caller}</p>
                <p><strong>接听方:</strong> {selectedCall.callee}</p>
                <p><strong>开始时间:</strong> {selectedCall.startTime}</p>
                <p><strong>结束时间:</strong> {selectedCall.endTime || '进行中'}</p>
                <p><strong>通话时长:</strong> {selectedCall.duration}</p>
              </Col>
              <Col span={12}>
                <p><strong>状态:</strong> {getStatusTag(selectedCall.status)}</p>
                <p><strong>类型:</strong> {getTypeTag(selectedCall.type)}</p>
                <p><strong>语言:</strong> {selectedCall.language}</p>
                <p><strong>译员:</strong> {selectedCall.translator || '无'}</p>
                <p><strong>服务评分:</strong> {selectedCall.quality > 0 ? `${selectedCall.quality}/5` : '未评分'}</p>
                <p><strong>费用:</strong> {selectedCall.cost > 0 ? `¥${selectedCall.cost.toFixed(2)}` : '免费'}</p>
              </Col>
            </Row>
          </div>
        )}
      </Modal>
    </div>
  );
};

export default CallList; 