import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  Row,
  Col,
  Statistic,
  Tooltip,
  DatePicker,
  Descriptions,
  Divider
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  ReloadOutlined,
  DollarOutlined,
  CreditCardOutlined,
  CheckCircleOutlined,
  CloseCircleOutlined,
  ExclamationCircleOutlined,
  DownloadOutlined,
  UndoOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';
import dayjs from 'dayjs';

const { Title } = Typography;
const { Option } = Select;
const { RangePicker } = DatePicker;

interface Payment {
  id: string;
  orderId: string;
  userId: string;
  userName: string;
  amount: number;
  paymentMethod: 'credit_card' | 'alipay' | 'wechat' | 'paypal';
  status: 'pending' | 'completed' | 'failed' | 'refunded' | 'cancelled';
  transactionId: string;
  serviceType: 'voice_call' | 'video_call' | 'document_translation' | 'appointment';
  serviceName: string;
  createdAt: string;
  completedAt?: string;
  refundAmount?: number;
  refundReason?: string;
  currency: string;
  fee: number; // 手续费
}

const PaymentList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [payments, setPayments] = useState<Payment[]>([]);
  const [filteredPayments, setFilteredPayments] = useState<Payment[]>([]);
  const [searchText, setSearchText] = useState('');
  const [statusFilter, setStatusFilter] = useState<string>('all');
  const [methodFilter, setMethodFilter] = useState<string>('all');
  const [dateRange, setDateRange] = useState<[dayjs.Dayjs, dayjs.Dayjs] | null>(null);
  const [selectedPayment, setSelectedPayment] = useState<Payment | null>(null);
  const [detailModalVisible, setDetailModalVisible] = useState(false);

  // 模拟数据
  const mockPayments: Payment[] = [
    {
      id: '1',
      orderId: 'ORD-2024-001',
      userId: 'U001',
      userName: '张三',
      amount: 150.00,
      paymentMethod: 'alipay',
      status: 'completed',
      transactionId: 'TXN-20240115-001',
      serviceType: 'voice_call',
      serviceName: '中英文语音翻译',
      createdAt: '2024-01-15 14:30:00',
      completedAt: '2024-01-15 14:31:00',
      currency: 'CNY',
      fee: 4.50
    },
    {
      id: '2',
      orderId: 'ORD-2024-002',
      userId: 'U002',
      userName: '李四',
      amount: 280.00,
      paymentMethod: 'wechat',
      status: 'completed',
      transactionId: 'TXN-20240115-002',
      serviceType: 'document_translation',
      serviceName: '商务文档翻译',
      createdAt: '2024-01-15 13:45:00',
      completedAt: '2024-01-15 13:46:00',
      currency: 'CNY',
      fee: 8.40
    },
    {
      id: '3',
      orderId: 'ORD-2024-003',
      userId: 'U003',
      userName: '王五',
      amount: 320.00,
      paymentMethod: 'credit_card',
      status: 'refunded',
      transactionId: 'TXN-20240115-003',
      serviceType: 'video_call',
      serviceName: '视频会议翻译',
      createdAt: '2024-01-15 12:20:00',
      completedAt: '2024-01-15 12:21:00',
      refundAmount: 320.00,
      refundReason: '服务质量问题',
      currency: 'CNY',
      fee: 9.60
    },
    {
      id: '4',
      orderId: 'ORD-2024-004',
      userId: 'U004',
      userName: '赵六',
      amount: 450.00,
      paymentMethod: 'paypal',
      status: 'pending',
      transactionId: 'TXN-20240115-004',
      serviceType: 'appointment',
      serviceName: '专业咨询预约',
      createdAt: '2024-01-15 16:10:00',
      currency: 'USD',
      fee: 13.50
    },
    {
      id: '5',
      orderId: 'ORD-2024-005',
      userId: 'U005',
      userName: '孙七',
      amount: 180.00,
      paymentMethod: 'alipay',
      status: 'failed',
      transactionId: 'TXN-20240115-005',
      serviceType: 'voice_call',
      serviceName: '法语口译服务',
      createdAt: '2024-01-15 11:30:00',
      currency: 'CNY',
      fee: 5.40
    }
  ];

  const fetchPayments = async () => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setPayments(mockPayments);
      setFilteredPayments(mockPayments);
      message.success('支付记录加载成功');
    } catch (error) {
      message.error('加载支付记录失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchPayments();
  }, []);

  useEffect(() => {
    let filtered = payments;

    if (searchText) {
      filtered = filtered.filter(payment => 
        payment.orderId.toLowerCase().includes(searchText.toLowerCase()) ||
        payment.userName.toLowerCase().includes(searchText.toLowerCase()) ||
        payment.transactionId.toLowerCase().includes(searchText.toLowerCase()) ||
        payment.serviceName.includes(searchText)
      );
    }

    if (statusFilter !== 'all') {
      filtered = filtered.filter(payment => payment.status === statusFilter);
    }

    if (methodFilter !== 'all') {
      filtered = filtered.filter(payment => payment.paymentMethod === methodFilter);
    }

    if (dateRange) {
      const [start, end] = dateRange;
      filtered = filtered.filter(payment => {
        const paymentDate = dayjs(payment.createdAt);
        return paymentDate.isAfter(start.startOf('day')) && paymentDate.isBefore(end.endOf('day'));
      });
    }

    setFilteredPayments(filtered);
  }, [payments, searchText, statusFilter, methodFilter, dateRange]);

  const getStatusTag = (status: string) => {
    const statusConfig = {
      pending: { color: 'orange', text: '待支付', icon: <ExclamationCircleOutlined /> },
      completed: { color: 'green', text: '已完成', icon: <CheckCircleOutlined /> },
      failed: { color: 'red', text: '支付失败', icon: <CloseCircleOutlined /> },
      refunded: { color: 'purple', text: '已退款', icon: <UndoOutlined /> },
      cancelled: { color: 'gray', text: '已取消', icon: <CloseCircleOutlined /> }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Tag color={config.color} icon={config.icon}>{config.text}</Tag>;
  };

  const getPaymentMethodTag = (method: string) => {
    const methodConfig = {
      credit_card: { color: 'blue', text: '信用卡' },
      alipay: { color: 'green', text: '支付宝' },
      wechat: { color: 'lime', text: '微信支付' },
      paypal: { color: 'gold', text: 'PayPal' }
    };
    const config = methodConfig[method as keyof typeof methodConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const handleViewDetail = (payment: Payment) => {
    setSelectedPayment(payment);
    setDetailModalVisible(true);
  };

  const columns: ColumnsType<Payment> = [
    {
      title: '订单号',
      dataIndex: 'orderId',
      key: 'orderId',
      width: 140,
      render: (orderId) => (
        <span style={{ fontFamily: 'monospace', fontSize: '12px' }}>
          {orderId}
        </span>
      )
    },
    {
      title: '用户',
      dataIndex: 'userName',
      key: 'userName',
      width: 100
    },
    {
      title: '金额',
      key: 'amount',
      width: 120,
      render: (_, record) => (
        <div>
          <div style={{ fontWeight: 'bold' }}>
            {record.currency} {record.amount.toFixed(2)}
          </div>
          <div style={{ fontSize: '12px', color: '#666' }}>
            手续费: {record.currency} {record.fee.toFixed(2)}
          </div>
        </div>
      )
    },
    {
      title: '支付方式',
      dataIndex: 'paymentMethod',
      key: 'paymentMethod',
      width: 120,
      render: getPaymentMethodTag
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 120,
      render: getStatusTag
    },
    {
      title: '服务类型',
      dataIndex: 'serviceName',
      key: 'serviceName',
      width: 150,
      ellipsis: true
    },
    {
      title: '交易时间',
      dataIndex: 'createdAt',
      key: 'createdAt',
      width: 160,
      render: (time) => dayjs(time).format('YYYY-MM-DD HH:mm:ss')
    },
    {
      title: '操作',
      key: 'action',
      width: 120,
      render: (_, record) => (
        <Space>
          <Tooltip title="查看详情">
            <Button
              type="primary"
              size="small"
              icon={<EyeOutlined />}
              onClick={() => handleViewDetail(record)}
            />
          </Tooltip>
          <Tooltip title="下载凭证">
            <Button
              size="small"
              icon={<DownloadOutlined />}
              disabled={record.status !== 'completed'}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  const stats = {
    total: filteredPayments.length,
    completed: filteredPayments.filter(p => p.status === 'completed').length,
    pending: filteredPayments.filter(p => p.status === 'pending').length,
    failed: filteredPayments.filter(p => p.status === 'failed').length,
    refunded: filteredPayments.filter(p => p.status === 'refunded').length,
    totalAmount: filteredPayments
      .filter(p => p.status === 'completed')
      .reduce((sum, p) => sum + p.amount, 0),
    totalFee: filteredPayments
      .filter(p => p.status === 'completed')
      .reduce((sum, p) => sum + p.fee, 0),
    refundAmount: filteredPayments
      .filter(p => p.status === 'refunded')
      .reduce((sum, p) => sum + (p.refundAmount || 0), 0)
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>支付记录</Title>

      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总交易数"
              value={stats.total}
              prefix={<CreditCardOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="成功交易"
              value={stats.completed}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="交易总额"
              value={stats.totalAmount}
              precision={2}
              prefix={<DollarOutlined />}
              valueStyle={{ color: '#fa8c16' }}
              suffix="CNY"
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="手续费收入"
              value={stats.totalFee}
              precision={2}
              valueStyle={{ color: '#722ed1' }}
              suffix="CNY"
            />
          </Card>
        </Col>
      </Row>

      <Card>
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={6}>
            <Input
              placeholder="搜索订单号、用户、交易号..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={4}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="pending">待支付</Option>
              <Option value="completed">已完成</Option>
              <Option value="failed">支付失败</Option>
              <Option value="refunded">已退款</Option>
              <Option value="cancelled">已取消</Option>
            </Select>
          </Col>
          <Col span={4}>
            <Select
              value={methodFilter}
              onChange={setMethodFilter}
              style={{ width: '100%' }}
              placeholder="支付方式"
            >
              <Option value="all">全部方式</Option>
              <Option value="credit_card">信用卡</Option>
              <Option value="alipay">支付宝</Option>
              <Option value="wechat">微信支付</Option>
              <Option value="paypal">PayPal</Option>
            </Select>
          </Col>
          <Col span={6}>
            <RangePicker
              style={{ width: '100%' }}
              value={dateRange}
              onChange={(dates) => setDateRange(dates as [dayjs.Dayjs, dayjs.Dayjs] | null)}
              placeholder={['开始日期', '结束日期']}
            />
          </Col>
          <Col span={4}>
            <Button
              icon={<ReloadOutlined />}
              onClick={fetchPayments}
              loading={loading}
              style={{ width: '100%' }}
            >
              刷新
            </Button>
          </Col>
        </Row>

        <Table
          columns={columns}
          dataSource={filteredPayments}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredPayments.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>

      <Modal
        title="支付详情"
        open={detailModalVisible}
        onCancel={() => setDetailModalVisible(false)}
        footer={[
          <Button key="close" onClick={() => setDetailModalVisible(false)}>
            关闭
          </Button>
        ]}
        width={600}
      >
        {selectedPayment && (
          <Descriptions column={2} bordered>
            <Descriptions.Item label="订单号" span={2}>
              {selectedPayment.orderId}
            </Descriptions.Item>
            <Descriptions.Item label="交易号" span={2}>
              {selectedPayment.transactionId}
            </Descriptions.Item>
            <Descriptions.Item label="用户">
              {selectedPayment.userName}
            </Descriptions.Item>
            <Descriptions.Item label="用户ID">
              {selectedPayment.userId}
            </Descriptions.Item>
            <Descriptions.Item label="服务类型" span={2}>
              {selectedPayment.serviceName}
            </Descriptions.Item>
            <Descriptions.Item label="支付金额">
              {selectedPayment.currency} {selectedPayment.amount.toFixed(2)}
            </Descriptions.Item>
            <Descriptions.Item label="手续费">
              {selectedPayment.currency} {selectedPayment.fee.toFixed(2)}
            </Descriptions.Item>
            <Descriptions.Item label="支付方式">
              {getPaymentMethodTag(selectedPayment.paymentMethod)}
            </Descriptions.Item>
            <Descriptions.Item label="状态">
              {getStatusTag(selectedPayment.status)}
            </Descriptions.Item>
            <Descriptions.Item label="创建时间" span={2}>
              {dayjs(selectedPayment.createdAt).format('YYYY-MM-DD HH:mm:ss')}
            </Descriptions.Item>
            {selectedPayment.completedAt && (
              <Descriptions.Item label="完成时间" span={2}>
                {dayjs(selectedPayment.completedAt).format('YYYY-MM-DD HH:mm:ss')}
              </Descriptions.Item>
            )}
            {selectedPayment.refundAmount && (
              <>
                <Descriptions.Item label="退款金额">
                  {selectedPayment.currency} {selectedPayment.refundAmount.toFixed(2)}
                </Descriptions.Item>
                <Descriptions.Item label="退款原因">
                  {selectedPayment.refundReason}
                </Descriptions.Item>
              </>
            )}
          </Descriptions>
        )}
      </Modal>
    </div>
  );
};

export default PaymentList; 