import React, { useState, useEffect } from 'react';
import { 
  Card, 
  Form, 
  Input, 
  Button, 
  Switch, 
  InputNumber, 
  Select, 
  Typography, 
  message,
  Row,
  Col,
  Divider,
  Tabs,
  Space,
  Alert,
  Badge
} from 'antd';
import { 
  SaveOutlined, 
  ReloadOutlined,
  SettingOutlined,
  DollarOutlined,
  PhoneOutlined,
  SecurityScanOutlined,
  NotificationOutlined,
  GlobalOutlined
} from '@ant-design/icons';

const { Title, Text } = Typography;
const { Option } = Select;
const { TextArea } = Input;

interface SystemConfig {
  // 基础设置
  siteName: string;
  siteDescription: string;
  supportEmail: string;
  supportPhone: string;
  defaultLanguage: string;
  timezone: string;
  
  // Twilio 设置
  twilioAccountSid: string;
  twilioAuthToken: string;
  twilioPhoneNumber: string;
  twilioWebhookUrl: string;
  enableVideoCall: boolean;
  enableVoiceCall: boolean;
  
  // 支付设置
  enableAlipay: boolean;
  enableWechatPay: boolean;
  enableCreditCard: boolean;
  enablePaypal: boolean;
  paymentFeeRate: number;
  minimumPayment: number;
  
  // 业务设置
  defaultCallDuration: number;
  maxCallDuration: number;
  translatorCommissionRate: number;
  autoAssignTranslator: boolean;
  requirePaymentUpfront: boolean;
  
  // 通知设置
  emailNotifications: boolean;
  smsNotifications: boolean;
  systemMaintenanceMode: boolean;
  
  // 安全设置
  enableTwoFactorAuth: boolean;
  sessionTimeout: number;
  maxLoginAttempts: number;
  passwordMinLength: number;
}

const SystemSettings: React.FC = () => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [config, setConfig] = useState<SystemConfig | null>(null);
  const [activeTab, setActiveTab] = useState('basic');

  // 模拟配置数据
  const mockConfig: SystemConfig = {
    siteName: 'Twilio翻译平台',
    siteDescription: '专业的实时翻译服务平台',
    supportEmail: 'support@twiliotranslate.com',
    supportPhone: '400-123-4567',
    defaultLanguage: 'zh-CN',
    timezone: 'Asia/Shanghai',
    
    twilioAccountSid: 'AC1234567890abcdef1234567890abcdef',
    twilioAuthToken: '********************************',
    twilioPhoneNumber: '+86-138-0013-8000',
    twilioWebhookUrl: 'https://api.twiliotranslate.com/webhook',
    enableVideoCall: true,
    enableVoiceCall: true,
    
    enableAlipay: true,
    enableWechatPay: true,
    enableCreditCard: true,
    enablePaypal: false,
    paymentFeeRate: 3.0,
    minimumPayment: 10.0,
    
    defaultCallDuration: 30,
    maxCallDuration: 120,
    translatorCommissionRate: 70.0,
    autoAssignTranslator: true,
    requirePaymentUpfront: true,
    
    emailNotifications: true,
    smsNotifications: false,
    systemMaintenanceMode: false,
    
    enableTwoFactorAuth: true,
    sessionTimeout: 30,
    maxLoginAttempts: 5,
    passwordMinLength: 8
  };

  const fetchConfig = async () => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setConfig(mockConfig);
      form.setFieldsValue(mockConfig);
      message.success('配置加载成功');
    } catch (error) {
      message.error('加载配置失败');
    } finally {
      setLoading(false);
    }
  };

  const handleSave = async (values: SystemConfig) => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1500));
      setConfig(values);
      message.success('配置保存成功');
    } catch (error) {
      message.error('保存配置失败');
    } finally {
      setLoading(false);
    }
  };

  const testTwilioConnection = async () => {
    message.loading('测试Twilio连接中...', 2);
    await new Promise(resolve => setTimeout(resolve, 2000));
    message.success('Twilio连接测试成功');
  };

  useEffect(() => {
    fetchConfig();
  }, []);

  const renderBasicSettings = () => (
    <Card title="基础设置" extra={<SettingOutlined />}>
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="网站名称"
            name="siteName"
            rules={[{ required: true, message: '请输入网站名称' }]}
          >
            <Input placeholder="请输入网站名称" />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="默认语言"
            name="defaultLanguage"
            rules={[{ required: true, message: '请选择默认语言' }]}
          >
            <Select placeholder="请选择默认语言">
              <Option value="zh-CN">简体中文</Option>
              <Option value="en-US">English</Option>
              <Option value="ja-JP">日本語</Option>
            </Select>
          </Form.Item>
        </Col>
      </Row>
      
      <Form.Item
        label="网站描述"
        name="siteDescription"
      >
        <TextArea rows={3} placeholder="请输入网站描述" />
      </Form.Item>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="客服邮箱"
            name="supportEmail"
            rules={[{ type: 'email', message: '请输入有效的邮箱地址' }]}
          >
            <Input placeholder="请输入客服邮箱" />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="客服电话"
            name="supportPhone"
          >
            <Input placeholder="请输入客服电话" />
          </Form.Item>
        </Col>
      </Row>
      
      <Form.Item
        label="时区"
        name="timezone"
      >
        <Select placeholder="请选择时区">
          <Option value="Asia/Shanghai">Asia/Shanghai (UTC+8)</Option>
          <Option value="America/New_York">America/New_York (UTC-5)</Option>
          <Option value="Europe/London">Europe/London (UTC+0)</Option>
        </Select>
      </Form.Item>
    </Card>
  );

  const renderTwilioSettings = () => (
    <Card 
      title="Twilio配置" 
      extra={
        <Space>
          <Badge status="success" text="已连接" />
          <Button size="small" onClick={testTwilioConnection}>
            测试连接
          </Button>
        </Space>
      }
    >
      <Alert
        message="Twilio配置说明"
        description="请确保您的Twilio账户有足够的余额，并且已经验证了电话号码。"
        type="info"
        showIcon
        style={{ marginBottom: 16 }}
      />
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="Account SID"
            name="twilioAccountSid"
            rules={[{ required: true, message: '请输入Account SID' }]}
          >
            <Input placeholder="请输入Twilio Account SID" />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="Auth Token"
            name="twilioAuthToken"
            rules={[{ required: true, message: '请输入Auth Token' }]}
          >
            <Input.Password placeholder="请输入Twilio Auth Token" />
          </Form.Item>
        </Col>
      </Row>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="电话号码"
            name="twilioPhoneNumber"
            rules={[{ required: true, message: '请输入电话号码' }]}
          >
            <Input placeholder="请输入Twilio电话号码" />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="Webhook URL"
            name="twilioWebhookUrl"
          >
            <Input placeholder="请输入Webhook URL" />
          </Form.Item>
        </Col>
      </Row>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="启用语音通话"
            name="enableVoiceCall"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="启用视频通话"
            name="enableVideoCall"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
      </Row>
    </Card>
  );

  const renderPaymentSettings = () => (
    <Card title="支付配置" extra={<DollarOutlined />}>
      <Row gutter={16}>
        <Col span={6}>
          <Form.Item
            label="支付宝"
            name="enableAlipay"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={6}>
          <Form.Item
            label="微信支付"
            name="enableWechatPay"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={6}>
          <Form.Item
            label="信用卡"
            name="enableCreditCard"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={6}>
          <Form.Item
            label="PayPal"
            name="enablePaypal"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
      </Row>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="手续费率 (%)"
            name="paymentFeeRate"
            rules={[{ required: true, message: '请输入手续费率' }]}
          >
            <InputNumber
              min={0}
              max={10}
              step={0.1}
              precision={1}
              style={{ width: '100%' }}
              placeholder="请输入手续费率"
            />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="最低支付金额"
            name="minimumPayment"
            rules={[{ required: true, message: '请输入最低支付金额' }]}
          >
            <InputNumber
              min={1}
              step={1}
              style={{ width: '100%' }}
              placeholder="请输入最低支付金额"
              addonAfter="CNY"
            />
          </Form.Item>
        </Col>
      </Row>
    </Card>
  );

  const renderBusinessSettings = () => (
    <Card title="业务配置" extra={<GlobalOutlined />}>
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="默认通话时长 (分钟)"
            name="defaultCallDuration"
            rules={[{ required: true, message: '请输入默认通话时长' }]}
          >
            <InputNumber
              min={5}
              max={180}
              style={{ width: '100%' }}
              placeholder="请输入默认通话时长"
            />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="最大通话时长 (分钟)"
            name="maxCallDuration"
            rules={[{ required: true, message: '请输入最大通话时长' }]}
          >
            <InputNumber
              min={10}
              max={300}
              style={{ width: '100%' }}
              placeholder="请输入最大通话时长"
            />
          </Form.Item>
        </Col>
      </Row>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="译员佣金比例 (%)"
            name="translatorCommissionRate"
            rules={[{ required: true, message: '请输入译员佣金比例' }]}
          >
            <InputNumber
              min={50}
              max={90}
              step={1}
              style={{ width: '100%' }}
              placeholder="请输入译员佣金比例"
            />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="自动分配译员"
            name="autoAssignTranslator"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
      </Row>
      
      <Form.Item
        label="要求预付费"
        name="requirePaymentUpfront"
        valuePropName="checked"
      >
        <Switch />
      </Form.Item>
    </Card>
  );

  const renderNotificationSettings = () => (
    <Card title="通知设置" extra={<NotificationOutlined />}>
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="邮件通知"
            name="emailNotifications"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="短信通知"
            name="smsNotifications"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
      </Row>
      
      <Form.Item
        label="系统维护模式"
        name="systemMaintenanceMode"
        valuePropName="checked"
      >
        <Switch />
      </Form.Item>
      
      {config?.systemMaintenanceMode && (
        <Alert
          message="维护模式已启用"
          description="系统当前处于维护模式，用户无法正常使用服务。"
          type="warning"
          showIcon
        />
      )}
    </Card>
  );

  const renderSecuritySettings = () => (
    <Card title="安全设置" extra={<SecurityScanOutlined />}>
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="启用双因素认证"
            name="enableTwoFactorAuth"
            valuePropName="checked"
          >
            <Switch />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="会话超时 (分钟)"
            name="sessionTimeout"
            rules={[{ required: true, message: '请输入会话超时时间' }]}
          >
            <InputNumber
              min={5}
              max={120}
              style={{ width: '100%' }}
              placeholder="请输入会话超时时间"
            />
          </Form.Item>
        </Col>
      </Row>
      
      <Row gutter={16}>
        <Col span={12}>
          <Form.Item
            label="最大登录尝试次数"
            name="maxLoginAttempts"
            rules={[{ required: true, message: '请输入最大登录尝试次数' }]}
          >
            <InputNumber
              min={3}
              max={10}
              style={{ width: '100%' }}
              placeholder="请输入最大登录尝试次数"
            />
          </Form.Item>
        </Col>
        <Col span={12}>
          <Form.Item
            label="密码最小长度"
            name="passwordMinLength"
            rules={[{ required: true, message: '请输入密码最小长度' }]}
          >
            <InputNumber
              min={6}
              max={20}
              style={{ width: '100%' }}
              placeholder="请输入密码最小长度"
            />
          </Form.Item>
        </Col>
      </Row>
    </Card>
  );

  const tabItems = [
    {
      key: 'basic',
      label: '基础设置',
      children: renderBasicSettings()
    },
    {
      key: 'twilio',
      label: 'Twilio配置',
      children: renderTwilioSettings()
    },
    {
      key: 'payment',
      label: '支付配置',
      children: renderPaymentSettings()
    },
    {
      key: 'business',
      label: '业务配置',
      children: renderBusinessSettings()
    },
    {
      key: 'notification',
      label: '通知设置',
      children: renderNotificationSettings()
    },
    {
      key: 'security',
      label: '安全设置',
      children: renderSecuritySettings()
    }
  ];

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>系统设置</Title>
      
      <Form
        form={form}
        layout="vertical"
        onFinish={handleSave}
        initialValues={config || {}}
      >
        <Tabs 
          activeKey={activeTab} 
          onChange={setActiveTab}
          items={tabItems}
        />
        
        <Divider />
        
        <Space>
          <Button
            type="primary"
            htmlType="submit"
            loading={loading}
            icon={<SaveOutlined />}
            size="large"
          >
            保存配置
          </Button>
          <Button
            onClick={fetchConfig}
            loading={loading}
            icon={<ReloadOutlined />}
            size="large"
          >
            重新加载
          </Button>
        </Space>
      </Form>
    </div>
  );
};

export default SystemSettings; 