import {
  BillingRule,
  UserAccount,
  CallRecord,
  RechargeRecord,
  ConsumptionRecord,
  BillingStats,
  CallType,
  TranslationType,
  UserType,
  BILLING_CONFIG,
} from '../types/billing';

class BillingService {
  private static instance: BillingService;

  public static getInstance(): BillingService {
    if (!BillingService.instance) {
      BillingService.instance = new BillingService();
    }
    return BillingService.instance;
  }

  // 计费规则管理
  async getBillingRules(): Promise<BillingRule[]> {
    // TODO: 替换为实际API调用
    return [
      {
        id: '1',
        name: '语音文字翻译',
        callType: CallType.VOICE,
        translationType: TranslationType.TEXT,
        pricePerMinute: 50,
        minimumCharge: 50,
        userType: UserType.INDIVIDUAL,
        isActive: true,
        createdAt: new Date(),
        updatedAt: new Date(),
      },
      {
        id: '2',
        name: '视频手语翻译',
        callType: CallType.VIDEO,
        translationType: TranslationType.SIGN_LANGUAGE,
        pricePerMinute: 100,
        minimumCharge: 100,
        userType: UserType.INDIVIDUAL,
        isActive: true,
        createdAt: new Date(),
        updatedAt: new Date(),
      },
      {
        id: '3',
        name: '视频真人翻译',
        callType: CallType.VIDEO,
        translationType: TranslationType.HUMAN_INTERPRETER,
        pricePerMinute: 200,
        minimumCharge: 200,
        userType: UserType.INDIVIDUAL,
        isActive: true,
        createdAt: new Date(),
        updatedAt: new Date(),
      },
    ];
  }

  async createBillingRule(rule: Omit<BillingRule, 'id' | 'createdAt' | 'updatedAt'>): Promise<BillingRule> {
    // TODO: 替换为实际API调用
    const newRule: BillingRule = {
      ...rule,
      id: Date.now().toString(),
      createdAt: new Date(),
      updatedAt: new Date(),
    };
    return newRule;
  }

  async updateBillingRule(id: string, updates: Partial<BillingRule>): Promise<BillingRule> {
    // TODO: 替换为实际API调用
    const existingRule = await this.getBillingRuleById(id);
    return {
      ...existingRule,
      ...updates,
      updatedAt: new Date(),
    };
  }

  async deleteBillingRule(id: string): Promise<void> {
    // TODO: 替换为实际API调用
    console.log('删除计费规则:', id);
  }

  async getBillingRuleById(id: string): Promise<BillingRule> {
    // TODO: 替换为实际API调用
    const rules = await this.getBillingRules();
    const rule = rules.find(r => r.id === id);
    if (!rule) {
      throw new Error('计费规则未找到');
    }
    return rule;
  }

  // 用户账户管理
  async getUserAccounts(page: number = 1, pageSize: number = 10): Promise<{
    accounts: UserAccount[];
    total: number;
  }> {
    // TODO: 替换为实际API调用
    const mockAccounts: UserAccount[] = [
      {
        id: '1',
        userId: 'user1',
        userType: UserType.INDIVIDUAL,
        balance: 5000,
        frozenBalance: 0,
        totalRecharge: 10000,
        totalConsumption: 5000,
        createdAt: new Date(),
        updatedAt: new Date(),
      },
      {
        id: '2',
        userId: 'user2',
        userType: UserType.ENTERPRISE,
        balance: 50000,
        frozenBalance: 5000,
        creditLimit: 100000,
        totalRecharge: 100000,
        totalConsumption: 50000,
        createdAt: new Date(),
        updatedAt: new Date(),
      },
    ];

    return {
      accounts: mockAccounts,
      total: mockAccounts.length,
    };
  }

  async getUserAccountById(userId: string): Promise<UserAccount> {
    // TODO: 替换为实际API调用
    const { accounts } = await this.getUserAccounts();
    const account = accounts.find(a => a.userId === userId);
    if (!account) {
      throw new Error('用户账户未找到');
    }
    return account;
  }

  async updateUserBalance(userId: string, amount: number, reason: string): Promise<UserAccount> {
    // TODO: 替换为实际API调用
    const account = await this.getUserAccountById(userId);
    account.balance += amount;
    account.updatedAt = new Date();
    
    // 记录消费记录
    if (amount !== 0) {
      await this.createConsumptionRecord({
        userId,
        relatedType: 'call',
        relatedId: 'admin-adjustment',
        amount: Math.abs(amount),
        balanceBefore: account.balance - amount,
        balanceAfter: account.balance,
        description: reason,
      });
    }

    return account;
  }

  async freezeUserBalance(userId: string, amount: number): Promise<UserAccount> {
    // TODO: 替换为实际API调用
    const account = await this.getUserAccountById(userId);
    if (account.balance < amount) {
      throw new Error('余额不足');
    }
    account.balance -= amount;
    account.frozenBalance += amount;
    account.updatedAt = new Date();
    return account;
  }

  async unfreezeUserBalance(userId: string, amount: number): Promise<UserAccount> {
    // TODO: 替换为实际API调用
    const account = await this.getUserAccountById(userId);
    if (account.frozenBalance < amount) {
      throw new Error('冻结余额不足');
    }
    account.frozenBalance -= amount;
    account.balance += amount;
    account.updatedAt = new Date();
    return account;
  }

  // 通话记录管理
  async getCallRecords(
    page: number = 1,
    pageSize: number = 10,
    filters?: {
      userId?: string;
      status?: string;
      startDate?: Date;
      endDate?: Date;
    }
  ): Promise<{
    records: CallRecord[];
    total: number;
  }> {
    // TODO: 替换为实际API调用
    const mockRecords: CallRecord[] = [
      {
        id: '1',
        userId: 'user1',
        callType: CallType.VOICE,
        translationType: TranslationType.TEXT,
        startTime: new Date(Date.now() - 3600000),
        endTime: new Date(),
        duration: 60,
        cost: 3000,
        status: 'completed',
        billingDetails: {
          baseRate: 50,
          totalMinutes: 60,
          totalCost: 3000,
        },
        createdAt: new Date(),
        qualityScore: 4.5,
        userRating: 5,
        userFeedback: '翻译质量很好',
      },
    ];

    return {
      records: mockRecords,
      total: mockRecords.length,
    };
  }

  async getCallRecordById(id: string): Promise<CallRecord> {
    // TODO: 替换为实际API调用
    const { records } = await this.getCallRecords();
    const record = records.find(r => r.id === id);
    if (!record) {
      throw new Error('通话记录未找到');
    }
    return record;
  }

  // 充值记录管理
  async getRechargeRecords(
    page: number = 1,
    pageSize: number = 10,
    filters?: {
      userId?: string;
      status?: string;
      startDate?: Date;
      endDate?: Date;
    }
  ): Promise<{
    records: RechargeRecord[];
    total: number;
  }> {
    // TODO: 替换为实际API调用
    const mockRecords: RechargeRecord[] = [
      {
        id: '1',
        userId: 'user1',
        amount: 10000,
        bonus: 500,
        paymentMethod: 'wechat',
        status: 'completed',
        transactionId: 'tx_123456',
        createdAt: new Date(),
        completedAt: new Date(),
      },
    ];

    return {
      records: mockRecords,
      total: mockRecords.length,
    };
  }

  async processRecharge(
    userId: string,
    amount: number,
    paymentMethod: string,
    transactionId: string
  ): Promise<RechargeRecord> {
    // TODO: 替换为实际API调用
    const bonus = this.calculateRechargeBonus(amount);
    
    const record: RechargeRecord = {
      id: Date.now().toString(),
      userId,
      amount,
      bonus,
      paymentMethod,
      status: 'completed',
      transactionId,
      createdAt: new Date(),
      completedAt: new Date(),
    };

    // 更新用户余额
    await this.updateUserBalance(userId, amount + bonus, `充值 ${amount/100}元，赠送 ${bonus/100}元`);

    return record;
  }

  // 消费记录管理
  async getConsumptionRecords(
    page: number = 1,
    pageSize: number = 10,
    filters?: {
      userId?: string;
      relatedType?: string;
      startDate?: Date;
      endDate?: Date;
    }
  ): Promise<{
    records: ConsumptionRecord[];
    total: number;
  }> {
    // TODO: 替换为实际API调用
    const mockRecords: ConsumptionRecord[] = [
      {
        id: '1',
        userId: 'user1',
        relatedType: 'call',
        relatedId: 'call_123',
        amount: 3000,
        balanceBefore: 8000,
        balanceAfter: 5000,
        description: '语音文字翻译通话费用',
        createdAt: new Date(),
      },
    ];

    return {
      records: mockRecords,
      total: mockRecords.length,
    };
  }

  async createConsumptionRecord(
    record: Omit<ConsumptionRecord, 'id' | 'createdAt'>
  ): Promise<ConsumptionRecord> {
    // TODO: 替换为实际API调用
    return {
      ...record,
      id: Date.now().toString(),
      createdAt: new Date(),
    };
  }

  // 统计数据
  async getBillingStats(
    startDate?: Date,
    endDate?: Date
  ): Promise<BillingStats> {
    // TODO: 替换为实际API调用
    return {
      totalRevenue: 1000000, // 10000元
      totalUsers: 1500,
      activeUsers: 800,
      totalCalls: 5000,
      totalAppointments: 1200,
      averageCallDuration: 45,
      averageCallCost: 2000, // 20元
      topServices: [
        { type: '语音文字翻译', count: 3000, revenue: 600000 },
        { type: '视频手语翻译', count: 1500, revenue: 300000 },
        { type: '视频真人翻译', count: 500, revenue: 100000 },
      ],
      revenueByDate: [
        { date: '2024-01-01', revenue: 50000 },
        { date: '2024-01-02', revenue: 60000 },
        { date: '2024-01-03', revenue: 55000 },
      ],
    };
  }

  // 工具方法
  private calculateRechargeBonus(amount: number): number {
    for (const rule of BILLING_CONFIG.RECHARGE_BONUS_RULES) {
      if (amount >= rule.minAmount) {
        return Math.floor(amount * rule.bonusPercentage / 100);
      }
    }
    return 0;
  }

  // 计算通话费用
  calculateCallCost(
    callType: CallType,
    translationType: TranslationType,
    duration: number,
    userType: UserType = UserType.INDIVIDUAL
  ): number {
    // TODO: 根据计费规则计算实际费用
    const baseRate = BILLING_CONFIG.DEFAULT_RATES[callType]?.[translationType] || 100;
    return Math.max(baseRate, baseRate * Math.ceil(duration));
  }

  // 检查用户余额是否充足
  async checkUserBalance(userId: string, requiredAmount: number): Promise<boolean> {
    const account = await this.getUserAccountById(userId);
    return account.balance >= requiredAmount;
  }

  // 扣费
  async deductBalance(
    userId: string,
    amount: number,
    relatedType: 'call' | 'appointment' | 'document',
    relatedId: string,
    description: string
  ): Promise<void> {
    const account = await this.getUserAccountById(userId);
    if (account.balance < amount) {
      throw new Error('余额不足');
    }

    await this.updateUserBalance(userId, -amount, description);
    await this.createConsumptionRecord({
      userId,
      relatedType,
      relatedId,
      amount,
      balanceBefore: account.balance,
      balanceAfter: account.balance - amount,
      description,
    });
  }
}

export default BillingService.getInstance(); 