// 用户相关类型
export interface User {
  id: string;
  username: string;
  email: string;
  phone: string;
  fullName: string;
  avatar?: string;
  role: 'user' | 'translator' | 'admin';
  status: 'active' | 'inactive' | 'suspended';
  preferredLanguages: string[];
  createdAt: string;
  updatedAt: string;
  lastLoginAt?: string;
  totalCalls: number;
  totalSpent: number;
  rating: number;
  verificationStatus: 'pending' | 'verified' | 'rejected';
}

// 译员相关类型
export interface Translator {
  id: string;
  userId: string;
  fullName: string;
  email: string;
  phone: string;
  avatar?: string;
  languages: string[];
  specializations: string[];
  status: 'available' | 'busy' | 'offline' | 'suspended';
  rating: number;
  totalCalls: number;
  totalEarnings: number;
  hourlyRate: number;
  certifications: Certification[];
  workingHours: WorkingHours;
  createdAt: string;
  updatedAt: string;
}

export interface Certification {
  id: string;
  name: string;
  issuer: string;
  issuedAt: string;
  expiresAt?: string;
  documentUrl?: string;
  verified: boolean;
}

export interface WorkingHours {
  monday: TimeSlot[];
  tuesday: TimeSlot[];
  wednesday: TimeSlot[];
  thursday: TimeSlot[];
  friday: TimeSlot[];
  saturday: TimeSlot[];
  sunday: TimeSlot[];
}

export interface TimeSlot {
  start: string; // HH:mm
  end: string;   // HH:mm
}

// 通话相关类型
export interface TranslationCall {
  id: string;
  userId: string;
  callId: string;
  clientName: string;
  clientPhone: string;
  type: 'ai' | 'human';
  status: 'pending' | 'connecting' | 'ongoing' | 'completed' | 'failed' | 'cancelled';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime?: string;
  duration?: number; // seconds
  cost: number;
  rating?: number;
  feedback?: string;
  translatorId?: string;
  translatorName?: string;
  translatorPhone?: string;
  recordingUrl?: string;
  transcription?: string;
  translation?: string;
  // 管理员字段
  adminNotes?: string;
  paymentStatus: 'pending' | 'paid' | 'refunded' | 'failed';
  refundAmount?: number;
  qualityScore?: number;
  issues?: string[];
}

// 文档翻译相关类型
export interface DocumentTranslation {
  id: string;
  userId: string;
  fileName: string;
  originalSize: number;
  fileUrl: string;
  translatedFileUrl?: string;
  sourceLanguage: string;
  targetLanguage: string;
  status: 'pending' | 'in_progress' | 'completed' | 'failed' | 'cancelled';
  progress: number;
  quality: 'basic' | 'professional' | 'premium';
  urgency: 'low' | 'normal' | 'high' | 'urgent';
  estimatedTime?: number; // minutes
  actualTime?: number;
  cost: number;
  translatorId?: string;
  translatorName?: string;
  rating?: number;
  feedback?: string;
  createdAt: string;
  completedAt?: string;
  // 管理员字段
  adminNotes?: string;
  paymentStatus: 'pending' | 'paid' | 'refunded' | 'failed';
  refundAmount?: number;
  qualityScore?: number;
  issues?: string[];
  retranslationCount?: number;
  clientName?: string;
  clientEmail?: string;
  clientPhone?: string;
}

// 预约相关类型
export interface Appointment {
  id: string;
  userId: string;
  translatorId?: string;
  title: string;
  description?: string;
  type: 'interpretation' | 'translation' | 'consultation';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime: string;
  status: 'pending' | 'confirmed' | 'in_progress' | 'completed' | 'cancelled';
  cost: number;
  meetingUrl?: string;
  notes?: string;
  reminderSent: boolean;
  createdAt: string;
  updatedAt: string;
  // 管理员字段
  clientName?: string;
  clientEmail?: string;
  clientPhone?: string;
  translatorName?: string;
  translatorEmail?: string;
  translatorPhone?: string;
  adminNotes?: string;
  paymentStatus: 'pending' | 'paid' | 'refunded' | 'failed';
  refundAmount?: number;
  qualityScore?: number;
  issues?: string[];
  rating?: number;
  feedback?: string;
  location?: string;
  urgency: 'low' | 'normal' | 'high' | 'urgent';
}

// 支付相关类型
export interface Payment {
  id: string;
  userId: string;
  type: 'call' | 'document' | 'appointment';
  relatedId: string; // callId, documentId, or appointmentId
  amount: number;
  currency: 'CNY' | 'USD' | 'EUR';
  status: 'pending' | 'processing' | 'completed' | 'failed' | 'refunded';
  paymentMethod: 'wechat' | 'alipay' | 'credit_card' | 'bank_transfer';
  transactionId?: string;
  refundAmount?: number;
  refundReason?: string;
  createdAt: string;
  completedAt?: string;
  // 管理员字段
  adminNotes?: string;
  clientName?: string;
  clientEmail?: string;
  description?: string;
}

// 系统配置类型
export interface SystemConfig {
  // 基本设置
  siteName: string;
  siteDescription: string;
  supportEmail: string;
  supportPhone: string;
  
  // Twilio设置
  twilioAccountSid: string;
  twilioAuthToken: string;
  twilioPhoneNumber: string;
  
  // 支付设置
  stripePublishableKey: string;
  stripeSecretKey: string;
  wechatPayMerchantId: string;
  alipayAppId: string;
  
  // 业务设置
  defaultCallRate: number;
  defaultDocumentRate: number;
  maxCallDuration: number;
  maxFileSize: number;
  supportedLanguages: string[];
  
  // 通知设置
  emailNotifications: boolean;
  smsNotifications: boolean;
  pushNotifications: boolean;
  
  // 安全设置
  requireEmailVerification: boolean;
  requirePhoneVerification: boolean;
  maxLoginAttempts: number;
  sessionTimeout: number;
}

// API响应类型
export interface ApiResponse<T = any> {
  success: boolean;
  data?: T;
  message?: string;
  error?: string;
}

// 分页类型
export interface PaginatedResponse<T> {
  data: T[];
  total: number;
  page: number;
  pageSize: number;
  totalPages: number;
}

// 统计数据类型
export interface DashboardStats {
  totalUsers: number;
  totalTranslators: number;
  totalCalls: number;
  totalDocuments: number;
  totalRevenue: number;
  activeUsers: number;
  onlineTranslators: number;
  ongoingCalls: number;
  pendingDocuments: number;
} 