import { FC, useState } from 'react';
import { useNavigate } from 'react-router-dom';

const DeviceTestPanel: FC = () => {
  const navigate = useNavigate();
  const [isVisible, setIsVisible] = useState(false);

  const testRoutes = [
    { path: '/mobile/home', label: '移动端首页', icon: '📱' },
    { path: '/mobile/call', label: '移动端通话', icon: '📞' },
    { path: '/mobile/documents', label: '移动端文档', icon: '📄' },
    { path: '/mobile/settings', label: '移动端设置', icon: '⚙️' },
    { path: '/dashboard', label: '管理后台', icon: '💻' },
  ];

  const styles = {
    toggle: {
      position: 'fixed' as const,
      top: '20px',
      right: '20px',
      zIndex: 9999,
      padding: '8px 12px',
      backgroundColor: '#1890ff',
      color: 'white',
      border: 'none',
      borderRadius: '6px',
      cursor: 'pointer',
      fontSize: '12px',
      fontWeight: '600' as const,
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.15)',
    },
    panel: {
      position: 'fixed' as const,
      top: '60px',
      right: '20px',
      zIndex: 9998,
      backgroundColor: 'white',
      borderRadius: '8px',
      padding: '16px',
      boxShadow: '0 4px 12px rgba(0, 0, 0, 0.15)',
      minWidth: '200px',
      border: '1px solid #e8e8e8',
    },
    title: {
      fontSize: '14px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '12px',
      textAlign: 'center' as const,
    },
    routeButton: {
      display: 'flex',
      alignItems: 'center',
      width: '100%',
      padding: '8px 12px',
      marginBottom: '4px',
      backgroundColor: 'transparent',
      border: '1px solid #e8e8e8',
      borderRadius: '4px',
      cursor: 'pointer',
      fontSize: '12px',
      transition: 'all 0.2s ease',
    },
    routeIcon: {
      marginRight: '8px',
      fontSize: '14px',
    },
    deviceInfo: {
      marginTop: '12px',
      padding: '8px',
      backgroundColor: '#f5f5f5',
      borderRadius: '4px',
      fontSize: '11px',
      color: '#666',
    },
  };

  const getCurrentDeviceInfo = () => {
    const width = window.innerWidth;
    const height = window.innerHeight;
    const userAgent = navigator.userAgent;
    const isMobile = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(userAgent);
    
    return {
      width,
      height,
      userAgent: userAgent.substring(0, 50) + '...',
      isMobile,
    };
  };

  const deviceInfo = getCurrentDeviceInfo();

  if (process.env.NODE_ENV === 'production') {
    return null; // 生产环境不显示测试面板
  }

  return (
    <>
      <button
        style={styles.toggle}
        onClick={() => setIsVisible(!isVisible)}
      >
        {isVisible ? '关闭' : '测试'}
      </button>
      
      {isVisible && (
        <div style={styles.panel}>
          <div style={styles.title}>🧪 设备测试面板</div>
          
          {testRoutes.map((route) => (
            <button
              key={route.path}
              style={styles.routeButton}
              onClick={() => {
                navigate(route.path);
                setIsVisible(false);
              }}
              onMouseEnter={(e) => {
                e.currentTarget.style.backgroundColor = '#f0f8ff';
                e.currentTarget.style.borderColor = '#1890ff';
              }}
              onMouseLeave={(e) => {
                e.currentTarget.style.backgroundColor = 'transparent';
                e.currentTarget.style.borderColor = '#e8e8e8';
              }}
            >
              <span style={styles.routeIcon}>{route.icon}</span>
              {route.label}
            </button>
          ))}
          
          <div style={styles.deviceInfo}>
            <div><strong>设备信息:</strong></div>
            <div>尺寸: {deviceInfo.width} x {deviceInfo.height}</div>
            <div>移动设备: {deviceInfo.isMobile ? '是' : '否'}</div>
            <div>UA: {deviceInfo.userAgent}</div>
          </div>
        </div>
      )}
    </>
  );
};

export default DeviceTestPanel; 