import * as React from 'react';
import { useState } from 'react';
import {
  Modal,
  Form,
  Input,
  Select,
  Button,
  Space,
  message,
  Radio,
  InputNumber,
  Switch,
  Divider,
} from 'antd';
import {
  PhoneOutlined,
  UserOutlined,
  TranslationOutlined,
  DollarOutlined,
  ClockCircleOutlined,
} from '@ant-design/icons';
import { api } from '@/utils/api';

const { Option } = Select;

interface NewCallModalProps {
  visible: boolean;
  onCancel: () => void;
  onSuccess: () => void;
}

interface CallFormData {
  clientName: string;
  clientPhone: string;
  type: 'ai' | 'human' | 'video' | 'sign';
  sourceLanguage: string;
  targetLanguage: string;
  urgency: 'normal' | 'urgent';
  estimatedDuration: number;
  notes?: string;
  translatorId?: string;
}

const NewCallModal: React.FC<NewCallModalProps> = ({
  visible,
  onCancel,
  onSuccess,
}) => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [callType, setCallType] = useState<'ai' | 'human' | 'video' | 'sign'>('ai');
  const [estimatedCost, setEstimatedCost] = useState(0);

  const languages = [
    { code: 'zh-CN', name: '中文' },
    { code: 'en-US', name: '英语' },
    { code: 'ja-JP', name: '日语' },
    { code: 'ko-KR', name: '韩语' },
    { code: 'fr-FR', name: '法语' },
    { code: 'de-DE', name: '德语' },
    { code: 'es-ES', name: '西班牙语' },
    { code: 'ru-RU', name: '俄语' },
  ];

  const translators = [
    { id: 'translator_1', name: '李翻译 - 中英专家', languages: ['zh-CN', 'en-US'] },
    { id: 'translator_2', name: '王翻译 - 日语专家', languages: ['zh-CN', 'ja-JP'] },
    { id: 'translator_3', name: '张翻译 - 多语言', languages: ['zh-CN', 'en-US', 'ko-KR'] },
  ];

  // 计算预估费用
  const calculateCost = (type: string, duration: number, urgency: string) => {
    const rates = {
      ai: 0.5,
      human: 2.0,
      video: 3.0,
      sign: 4.0,
    };
    
    const baseRate = rates[type as keyof typeof rates] || 1.0;
    const urgencyMultiplier = urgency === 'urgent' ? 1.5 : 1.0;
    
    return baseRate * duration * urgencyMultiplier;
  };

  const handleFormChange = () => {
    const values = form.getFieldsValue();
    if (values.type && values.estimatedDuration) {
      const cost = calculateCost(values.type, values.estimatedDuration, values.urgency || 'normal');
      setEstimatedCost(cost);
    }
  };

  const handleSubmit = async (values: CallFormData) => {
    try {
      setLoading(true);
      
      // 调用API创建通话
      const callData = {
        ...values,
        cost: estimatedCost,
        status: 'pending',
        startTime: new Date().toISOString(),
      };
      
      // 模拟API调用
      await api.initiateCall({
        from: '+86123456789', // 系统电话号码
        to: values.clientPhone,
        sourceLanguage: values.sourceLanguage,
        targetLanguage: values.targetLanguage,
        type: values.type
      });
      
      message.success('通话创建成功！');
      form.resetFields();
      setEstimatedCost(0);
      onSuccess();
    } catch (error) {
      console.error('创建通话失败:', error);
      message.error('创建通话失败，请重试');
    } finally {
      setLoading(false);
    }
  };

  const handleCancel = () => {
    form.resetFields();
    setEstimatedCost(0);
    setCallType('ai');
    onCancel();
  };

  return (
    <Modal
      title={
        <Space>
          <PhoneOutlined />
          发起新通话
        </Space>
      }
      visible={visible}
      onCancel={handleCancel}
      footer={null}
      width={600}
      destroyOnClose
    >
      <Form
        form={form}
        layout="vertical"
        onFinish={handleSubmit}
        onValuesChange={handleFormChange}
        initialValues={{
          type: 'ai',
          urgency: 'normal',
          estimatedDuration: 30,
        }}
      >
        {/* 客户信息 */}
        <Divider orientation="left">客户信息</Divider>
        
        <Form.Item
          name="clientName"
          label="客户姓名"
          rules={[{ required: true, message: '请输入客户姓名' }]}
        >
          <Input
            prefix={<UserOutlined />}
            placeholder="请输入客户姓名"
          />
        </Form.Item>

        <Form.Item
          name="clientPhone"
          label="客户电话"
          rules={[
            { required: true, message: '请输入客户电话' },
            { pattern: /^1[3-9]\d{9}$/, message: '请输入正确的手机号码' }
          ]}
        >
          <Input
            prefix={<PhoneOutlined />}
            placeholder="请输入客户电话号码"
          />
        </Form.Item>

        {/* 服务配置 */}
        <Divider orientation="left">服务配置</Divider>

        <Form.Item
          name="type"
          label="翻译类型"
          rules={[{ required: true, message: '请选择翻译类型' }]}
        >
          <Radio.Group
            onChange={(e) => setCallType(e.target.value)}
            buttonStyle="solid"
          >
            <Radio.Button value="ai">🤖 AI翻译</Radio.Button>
            <Radio.Button value="human">👤 人工翻译</Radio.Button>
            <Radio.Button value="video">📹 视频通话</Radio.Button>
            <Radio.Button value="sign">🤟 手语翻译</Radio.Button>
          </Radio.Group>
        </Form.Item>

        <div style={{ display: 'flex', gap: '16px' }}>
          <Form.Item
            name="sourceLanguage"
            label="源语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择源语言' }]}
          >
            <Select placeholder="选择源语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>

          <Form.Item
            name="targetLanguage"
            label="目标语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择目标语言' }]}
          >
            <Select placeholder="选择目标语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>
        </div>

        {/* 人工翻译时显示译员选择 */}
        {(callType === 'human' || callType === 'video' || callType === 'sign') && (
          <Form.Item
            name="translatorId"
            label="指定译员"
          >
            <Select placeholder="选择译员（可选，系统会自动分配）" allowClear>
              {translators.map(translator => (
                <Option key={translator.id} value={translator.id}>
                  {translator.name}
                </Option>
              ))}
            </Select>
          </Form.Item>
        )}

        <div style={{ display: 'flex', gap: '16px' }}>
          <Form.Item
            name="estimatedDuration"
            label="预估时长（分钟）"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请输入预估时长' }]}
          >
            <InputNumber
              min={5}
              max={480}
              placeholder="预估通话时长"
              style={{ width: '100%' }}
              addonAfter="分钟"
            />
          </Form.Item>

          <Form.Item
            name="urgency"
            label="紧急程度"
            style={{ flex: 1 }}
          >
            <Select>
              <Option value="normal">普通</Option>
              <Option value="urgent">紧急 (+50% 费用)</Option>
            </Select>
          </Form.Item>
        </div>

        <Form.Item
          name="notes"
          label="备注说明"
        >
          <Input.TextArea
            rows={3}
            placeholder="请输入特殊要求或备注信息..."
          />
        </Form.Item>

        {/* 费用预估 */}
        {estimatedCost > 0 && (
          <div style={{
            background: '#f6f6f6',
            padding: '16px',
            borderRadius: '6px',
            marginBottom: '16px'
          }}>
            <Space>
              <DollarOutlined style={{ color: '#1890ff' }} />
              <span><strong>预估费用：</strong></span>
              <span style={{ fontSize: '18px', color: '#1890ff', fontWeight: 'bold' }}>
                ¥{estimatedCost.toFixed(2)}
              </span>
            </Space>
          </div>
        )}

        <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
          <Space>
            <Button onClick={handleCancel}>
              取消
            </Button>
            <Button type="primary" htmlType="submit" loading={loading}>
              发起通话
            </Button>
          </Space>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default NewCallModal; 