import React, { useState, useEffect, useRef } from 'react';
import { Button, Card, Row, Col, Space, Typography, message, Badge, Statistic } from 'antd';
import { 
  PhoneOutlined, 
  VideoCameraOutlined, 
  AudioOutlined, 
  AudioMutedOutlined,
  VideoCameraAddOutlined,
  StopOutlined,
  WalletOutlined,
  ClockCircleOutlined
} from '@ant-design/icons';
import { Room, RemoteParticipant, LocalParticipant } from 'twilio-video';
import { twilioService, VideoCallOptions, ParticipantInfo } from '../../services/twilioService';
import { BillingService } from '../../services/billingService';
import { CallType, TranslationType, UserAccount, UserType } from '../../types/billing';

const { Title, Text } = Typography;

interface VideoCallProps {
  roomName: string;
  identity: string;
  callType?: CallType;
  translationType?: TranslationType;
  onLeave?: () => void;
  onBillingUpdate?: (cost: number, duration: number) => void;
}

interface ParticipantVideoProps {
  participant: RemoteParticipant | LocalParticipant;
  isLocal: boolean;
}

const ParticipantVideo: React.FC<ParticipantVideoProps> = ({ participant, isLocal }) => {
  const videoRef = useRef<HTMLVideoElement>(null);
  const audioRef = useRef<HTMLAudioElement>(null);

  useEffect(() => {
    let videoTrack: any = null;
    let audioTrack: any = null;
    
    // 获取第一个视频轨道
    participant.videoTracks.forEach((track) => {
      if (!videoTrack) videoTrack = track;
    });
    
    // 获取第一个音频轨道
    participant.audioTracks.forEach((track) => {
      if (!audioTrack) audioTrack = track;
    });

    if (videoTrack && videoRef.current) {
      videoTrack.track?.attach(videoRef.current);
    }

    if (audioTrack && audioRef.current && !isLocal) {
      audioTrack.track?.attach(audioRef.current);
    }

    return () => {
      if (videoTrack?.track) {
        videoTrack.track.detach();
      }
      if (audioTrack?.track && !isLocal) {
        audioTrack.track.detach();
      }
    };
  }, [participant, isLocal]);

  return (
    <div className="participant-video" style={{ position: 'relative', width: '100%', height: '200px' }}>
      <video
        ref={videoRef}
        autoPlay
        muted={isLocal}
        style={{
          width: '100%',
          height: '100%',
          objectFit: 'cover',
          borderRadius: '8px',
        }}
      />
      {!isLocal && <audio ref={audioRef} autoPlay />}
      <div
        style={{
          position: 'absolute',
          bottom: '8px',
          left: '8px',
          background: 'rgba(0,0,0,0.6)',
          color: 'white',
          padding: '4px 8px',
          borderRadius: '4px',
          fontSize: '12px',
        }}
      >
        {participant.identity} {isLocal && '(您)'}
      </div>
    </div>
  );
};

export const VideoCall: React.FC<VideoCallProps> = ({ 
  roomName, 
  identity, 
  callType = CallType.VIDEO,
  translationType = TranslationType.SIGN_LANGUAGE,
  onLeave,
  onBillingUpdate 
}) => {
  const [room, setRoom] = useState<Room | null>(null);
  const [participants, setParticipants] = useState<ParticipantInfo[]>([]);
  const [isConnecting, setIsConnecting] = useState(false);
  const [isConnected, setIsConnected] = useState(false);
  const [audioEnabled, setAudioEnabled] = useState(true);
  const [videoEnabled, setVideoEnabled] = useState(true);
  
  // 计费相关状态
  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [callDuration, setCallDuration] = useState(0);
  const [currentCost, setCurrentCost] = useState(0);
  const [billingService] = useState(() => BillingService.getInstance());
  const [lastBillingMinute, setLastBillingMinute] = useState(0);
  
  const callStartTime = useRef<Date | null>(null);
  const durationInterval = useRef<NodeJS.Timeout | null>(null);
  const billingInterval = useRef<NodeJS.Timeout | null>(null);

  // 初始化用户账户信息
  useEffect(() => {
    const initUserAccount = async () => {
      try {
        // 模拟用户账户数据
        const mockAccount: UserAccount = {
          id: 'user-123',
          userType: UserType.INDIVIDUAL,
          balance: 10000, // 100元
        };
        billingService.setUserAccount(mockAccount);
        setUserAccount(mockAccount);
      } catch (error) {
        console.error('获取用户账户失败:', error);
        message.error('获取用户账户信息失败');
      }
    };

    initUserAccount();
  }, [billingService]);

  // 检查余额是否足够
  const checkBalance = () => {
    if (!userAccount) return false;
    
    const balanceCheck = billingService.checkBalance(callType, translationType, 1);
    if (!balanceCheck.sufficient) {
      message.error(`余额不足，需要至少 ¥${(balanceCheck.requiredAmount / 100).toFixed(2)} 才能开始通话`);
      return false;
    }
    
    const shouldWarn = billingService.shouldShowLowBalanceWarning(callType, translationType);
    if (shouldWarn) {
      message.warning('账户余额较低，请及时充值');
    }
    
    return true;
  };

  // 开始计费
  const startBilling = () => {
    callStartTime.current = new Date();
    
    // 每秒更新通话时长
    durationInterval.current = setInterval(() => {
      if (callStartTime.current) {
        const duration = Math.floor((Date.now() - callStartTime.current.getTime()) / 1000);
        setCallDuration(duration);
      }
    }, 1000);

    // 每分钟进行计费
    billingInterval.current = setInterval(() => {
      if (callStartTime.current) {
        const currentMinute = Math.floor((Date.now() - callStartTime.current.getTime()) / 60000);
        if (currentMinute > lastBillingMinute) {
          performBilling(currentMinute);
          setLastBillingMinute(currentMinute);
        }
      }
    }, 60000); // 每分钟检查一次
  };

  // 执行计费
  const performBilling = async (minute: number) => {
    if (!userAccount) return;

    try {
      const cost = billingService.calculateCallCost(callType, translationType, 1);
      const newTotalCost = currentCost + cost;
      
      // 检查余额是否足够继续通话
      const balanceCheck = billingService.checkBalance(callType, translationType, 1);
      if (!balanceCheck.sufficient) {
        message.error('余额不足，通话即将结束');
        setTimeout(() => {
          handleForceDisconnect();
        }, 30000); // 30秒后强制断开
        return;
      }

      // 扣费
      const deductSuccess = billingService.deductBalance(cost);
      if (deductSuccess) {
        setCurrentCost(newTotalCost);
        const updatedAccount = billingService.getUserAccount();
        setUserAccount(updatedAccount);
        
        // 通知父组件计费更新
        onBillingUpdate?.(newTotalCost, callDuration);
        
        const shouldWarn = billingService.shouldShowLowBalanceWarning(callType, translationType);
        if (shouldWarn) {
          message.warning('账户余额较低，请及时充值');
        }
      } else {
        message.error('扣费失败，通话即将结束');
        handleForceDisconnect();
      }
    } catch (error) {
      console.error('计费失败:', error);
      message.error('计费系统异常');
    }
  };

  // 强制断开连接（余额不足）
  const handleForceDisconnect = () => {
    message.error('余额不足，通话已结束');
    leaveRoom();
  };

  // 停止计费
  const stopBilling = () => {
    if (durationInterval.current) {
      clearInterval(durationInterval.current);
      durationInterval.current = null;
    }
    
    if (billingInterval.current) {
      clearInterval(billingInterval.current);
      billingInterval.current = null;
    }
    
    callStartTime.current = null;
    setLastBillingMinute(0);
  };

  const connectToRoom = async () => {
    if (isConnecting) return;

    // 检查余额
    if (!checkBalance()) {
      return;
    }

    setIsConnecting(true);
    try {
      const options: VideoCallOptions = {
        roomName,
        identity,
        audio: audioEnabled,
        video: videoEnabled,
      };

      const connectedRoom = await twilioService.connectToRoom(options);
      setRoom(connectedRoom);
      setIsConnected(true);
      
      setupRoomEventListeners(connectedRoom);
      startBilling(); // 开始计费
      
      message.success('成功连接到视频通话');
    } catch (error) {
      console.error('连接失败:', error);
      message.error('连接视频通话失败');
    } finally {
      setIsConnecting(false);
    }
  };

  const setupRoomEventListeners = (room: Room) => {
    const updateParticipants = () => {
      setParticipants(twilioService.getParticipants());
    };

    room.on('participantConnected', (participant: RemoteParticipant) => {
      message.info(`${participant.identity} 加入了通话`);
      updateParticipants();
    });

    room.on('participantDisconnected', (participant: RemoteParticipant) => {
      message.info(`${participant.identity} 离开了通话`);
      updateParticipants();
    });

    room.on('disconnected', () => {
      setIsConnected(false);
      setRoom(null);
      setParticipants([]);
      stopBilling(); // 停止计费
      message.info('已断开视频通话连接');
    });

    updateParticipants();
  };

  const leaveRoom = () => {
    twilioService.disconnect();
    setIsConnected(false);
    setRoom(null);
    setParticipants([]);
    stopBilling(); // 停止计费
    onLeave?.();
  };

  const toggleAudio = () => {
    const newAudioState = twilioService.toggleAudio();
    setAudioEnabled(newAudioState);
  };

  const toggleVideo = () => {
    const newVideoState = twilioService.toggleVideo();
    setVideoEnabled(newVideoState);
  };

  const formatDuration = (seconds: number): string => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };

  const formatCost = (cents: number): string => {
    return (cents / 100).toFixed(2);
  };

  useEffect(() => {
    return () => {
      twilioService.disconnect();
      stopBilling();
    };
  }, []);

  if (!isConnected) {
    return (
      <Card style={{ width: '100%', maxWidth: '500px', margin: '0 auto' }}>
        <div style={{ textAlign: 'center' }}>
          <Title level={4}>视频通话</Title>
          <Text>房间: {roomName}</Text>
          <br />
          <Text>身份: {identity}</Text>
          <br />
          <Text>通话类型: {callType === CallType.VIDEO ? '视频通话' : '语音通话'}</Text>
          <br />
          <Text>翻译类型: {translationType === TranslationType.SIGN_LANGUAGE ? '手语翻译' : translationType === TranslationType.TEXT ? '文字翻译' : '真人翻译'}</Text>
          <br /><br />
          
          {/* 用户账户信息 */}
          {userAccount && (
            <Card size="small" style={{ marginBottom: '16px', backgroundColor: '#f8f9fa' }}>
              <Row gutter={16}>
                <Col span={12}>
                  <Statistic
                    title="账户余额"
                    value={userAccount.balance / 100}
                    precision={2}
                    prefix="¥"
                    valueStyle={{ fontSize: '16px' }}
                  />
                </Col>
                <Col span={12}>
                  <Statistic
                    title="预计费率"
                    value={billingService.calculateCallCost(callType, translationType, 1) / 100}
                    precision={2}
                    prefix="¥"
                    suffix="/分钟"
                    valueStyle={{ fontSize: '16px' }}
                  />
                </Col>
              </Row>
            </Card>
          )}
          
          <Space direction="vertical" style={{ width: '100%' }}>
            <Row gutter={16}>
              <Col span={12}>
                <Button
                  type={audioEnabled ? 'primary' : 'default'}
                  icon={audioEnabled ? <AudioOutlined /> : <AudioMutedOutlined />}
                  onClick={() => setAudioEnabled(!audioEnabled)}
                  style={{ width: '100%' }}
                >
                  {audioEnabled ? '音频开启' : '音频关闭'}
                </Button>
              </Col>
              <Col span={12}>
                <Button
                  type={videoEnabled ? 'primary' : 'default'}
                  icon={<VideoCameraOutlined />}
                  onClick={() => setVideoEnabled(!videoEnabled)}
                  style={{ width: '100%' }}
                >
                  {videoEnabled ? '视频开启' : '视频关闭'}
                </Button>
              </Col>
            </Row>
            
            <Button
              type="primary"
              size="large"
              icon={<VideoCameraAddOutlined />}
              loading={isConnecting}
              onClick={connectToRoom}
              style={{ width: '100%' }}
              disabled={!userAccount}
            >
              {isConnecting ? '连接中...' : '加入通话'}
            </Button>
          </Space>
        </div>
      </Card>
    );
  }

  return (
    <div style={{ width: '100%', height: '100vh', padding: '16px' }}>
      <Card style={{ height: '100%' }}>
        <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
          {/* 通话信息和计费状态 */}
          <div style={{ marginBottom: '16px' }}>
            <Row gutter={16} align="middle">
              <Col span={8}>
                <Title level={4} style={{ margin: 0 }}>视频通话 - {roomName}</Title>
                <Text type="secondary">参与者: {participants.length}</Text>
              </Col>
              <Col span={8} style={{ textAlign: 'center' }}>
                <Badge status="processing" />
                <Space>
                  <ClockCircleOutlined />
                  <Text strong>{formatDuration(callDuration)}</Text>
                </Space>
              </Col>
              <Col span={8} style={{ textAlign: 'right' }}>
                <Space>
                  <WalletOutlined />
                  <Text strong>¥{formatCost(currentCost)}</Text>
                  {userAccount && (
                    <Text type="secondary">
                      (余额: ¥{formatCost(userAccount.balance)})
                    </Text>
                  )}
                </Space>
              </Col>
            </Row>
          </div>

          <div style={{ flex: 1, overflow: 'auto' }}>
            <Row gutter={[16, 16]}>
              {participants.map((participantInfo) => {
                const participant = participantInfo.isLocal 
                  ? room?.localParticipant 
                  : Array.from(room?.participants.values() || []).find(p => p.sid === participantInfo.sid);
                
                if (!participant) return null;

                return (
                  <Col xs={24} sm={12} md={8} key={participantInfo.sid}>
                    <ParticipantVideo
                      participant={participant}
                      isLocal={participantInfo.isLocal}
                    />
                  </Col>
                );
              })}
            </Row>
          </div>

          {/* 控制按钮 */}
          <div style={{ marginTop: '16px', textAlign: 'center' }}>
            <Space size="large">
              <Button
                type={audioEnabled ? 'default' : 'primary'}
                danger={!audioEnabled}
                icon={audioEnabled ? <AudioOutlined /> : <AudioMutedOutlined />}
                onClick={toggleAudio}
                size="large"
              >
                {audioEnabled ? '静音' : '取消静音'}
              </Button>
              
              <Button
                type={videoEnabled ? 'default' : 'primary'}
                danger={!videoEnabled}
                icon={<VideoCameraOutlined />}
                onClick={toggleVideo}
                size="large"
              >
                {videoEnabled ? '关闭视频' : '开启视频'}
              </Button>
              
              <Button
                danger
                type="primary"
                icon={<StopOutlined />}
                onClick={leaveRoom}
                size="large"
              >
                结束通话
              </Button>
            </Space>
          </div>
        </div>
      </Card>
    </div>
  );
}; 