import { FC, useState, useEffect, useRef } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';
import { BillingService } from '../../services/billingService';
import { AppointmentService } from '../../services/appointmentService';
import { 
  UserAccount, 
  CallType, 
  TranslationType, 
  Interpreter,
  BillingRule 
} from '../../types/billing';

const MobileCall: FC = () => {
  const navigate = useNavigate();
  const location = useLocation();
  const billingService = BillingService.getInstance();
  const appointmentService = AppointmentService.getInstance();
  
  // 从URL参数获取通话类型
  const urlParams = new URLSearchParams(location.search);
  const initialCallType = urlParams.get('type') === 'video' ? CallType.VIDEO : CallType.VOICE;
  
  // 状态管理
  const [callType, setCallType] = useState<CallType>(initialCallType);
  const [translationType, setTranslationType] = useState<TranslationType>(
    callType === CallType.VIDEO ? TranslationType.SIGN_LANGUAGE : TranslationType.TEXT
  );
  const [isConnected, setIsConnected] = useState(false);
  const [callDuration, setCallDuration] = useState(0);
  const [currentCost, setCurrentCost] = useState(0);
  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [selectedInterpreter, setSelectedInterpreter] = useState<Interpreter | null>(null);
  const [availableInterpreters, setAvailableInterpreters] = useState<Interpreter[]>([]);
  const [billingRule, setBillingRule] = useState<BillingRule | null>(null);
  const [showLowBalanceWarning, setShowLowBalanceWarning] = useState(false);
  const [selectedLanguages, setSelectedLanguages] = useState({
    from: 'zh-CN',
    to: 'en-US',
  });

  // 计费相关
  const [lastBillingMinute, setLastBillingMinute] = useState(0);
  const billingIntervalRef = useRef<NodeJS.Timeout | null>(null);

  // 翻译历史
  const [translationHistory, setTranslationHistory] = useState([
    { 
      time: '14:23:15', 
      original: '你好，很高兴见到你', 
      translated: 'Hello, nice to meet you', 
      speaker: 'you' 
    },
    { 
      time: '14:23:18', 
      original: 'Nice to meet you too!', 
      translated: '我也很高兴见到你！', 
      speaker: 'other' 
    },
  ]);

  const languages = [
    { code: 'zh-CN', name: '中文', flag: '🇨🇳' },
    { code: 'en-US', name: 'English', flag: '🇺🇸' },
    { code: 'ja-JP', name: '日本語', flag: '🇯🇵' },
    { code: 'ko-KR', name: '한국어', flag: '🇰🇷' },
    { code: 'es-ES', name: 'Español', flag: '🇪🇸' },
    { code: 'fr-FR', name: 'Français', flag: '🇫🇷' },
    { code: 'de-DE', name: 'Deutsch', flag: '🇩🇪' },
  ];

  useEffect(() => {
    // 获取用户账户信息
    const account = billingService.getUserAccount();
    setUserAccount(account);

    // 获取计费规则
    if (account) {
      const rule = billingService.getBillingRule(callType, translationType, account.userType);
      setBillingRule(rule);
    }

    // 获取可用翻译员
    if (translationType === TranslationType.HUMAN_INTERPRETER) {
      const interpreters = appointmentService.getAvailableInterpreters(
        new Date(),
        [selectedLanguages.from, selectedLanguages.to]
      );
      setAvailableInterpreters(interpreters);
    }
  }, [callType, translationType, selectedLanguages]);

  useEffect(() => {
    let interval: NodeJS.Timeout;
    if (isConnected) {
      interval = setInterval(() => {
        setCallDuration(prev => {
          const newDuration = prev + 1;
          const currentMinute = Math.ceil(newDuration / 60);
          
          // 计算当前费用
          if (billingRule && userAccount) {
            const interpreterRate = selectedInterpreter?.pricePerMinute;
            const cost = billingService.calculateCallCost(
              callType, 
              translationType, 
              newDuration / 60,
              interpreterRate
            );
            setCurrentCost(cost);

            // 每分钟开始时扣费
            if (currentMinute > lastBillingMinute) {
              const minuteCost = billingService.calculateCallCost(
                callType, 
                translationType, 
                1,
                interpreterRate
              );
              
              if (billingService.deductBalance(minuteCost)) {
                setLastBillingMinute(currentMinute);
                setUserAccount(billingService.getUserAccount());
              } else {
                // 余额不足，断开通话
                handleDisconnect();
                alert('余额不足，通话已断开');
              }
            }

            // 检查低余额警告
            if (billingService.shouldShowLowBalanceWarning(callType, translationType, interpreterRate)) {
              setShowLowBalanceWarning(true);
            }
          }
          
          return newDuration;
        });
      }, 1000);
    }
    return () => clearInterval(interval);
  }, [isConnected, billingRule, userAccount, selectedInterpreter, lastBillingMinute]);

  const formatDuration = (seconds: number) => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };

  const formatCost = (cents: number) => {
    return (cents / 100).toFixed(2);
  };

  const handleConnect = () => {
    if (!userAccount || !billingRule) {
      alert('账户信息或计费规则未加载');
      return;
    }

    const interpreterRate = selectedInterpreter?.pricePerMinute;
    const balanceCheck = billingService.checkBalance(callType, translationType, 1, interpreterRate);
    
    if (!balanceCheck.sufficient) {
      alert(`余额不足，需要至少 ¥${formatCost(balanceCheck.requiredAmount)} 才能开始通话`);
      navigate('/mobile/recharge');
      return;
    }

    setIsConnected(true);
    setCallDuration(0);
    setCurrentCost(0);
    setLastBillingMinute(0);
  };

  const handleDisconnect = () => {
    setIsConnected(false);
    if (billingIntervalRef.current) {
      clearInterval(billingIntervalRef.current);
    }
  };

  const handleCallTypeChange = (newCallType: CallType) => {
    if (isConnected) {
      alert('通话进行中无法切换类型');
      return;
    }
    
    setCallType(newCallType);
    // 根据通话类型设置默认翻译类型
    if (newCallType === CallType.VIDEO) {
      setTranslationType(TranslationType.SIGN_LANGUAGE);
    } else {
      setTranslationType(TranslationType.TEXT);
    }
  };

  const handleTranslationTypeChange = (newTranslationType: TranslationType) => {
    if (isConnected) {
      alert('通话进行中无法切换翻译类型');
      return;
    }
    setTranslationType(newTranslationType);
  };

  const handleInterpreterSelect = (interpreter: Interpreter) => {
    if (isConnected) {
      alert('通话进行中无法切换翻译员');
      return;
    }
    setSelectedInterpreter(interpreter);
  };

  const swapLanguages = () => {
    setSelectedLanguages({
      from: selectedLanguages.to,
      to: selectedLanguages.from,
    });
  };

  const styles = {
    container: {
      padding: '16px',
      backgroundColor: '#f5f5f5',
      minHeight: '100vh',
      display: 'flex',
      flexDirection: 'column' as const,
    },
    header: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      marginBottom: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    callTypeSelector: {
      display: 'flex',
      gap: '8px',
      marginBottom: '16px',
    },
    callTypeButton: (active: boolean) => ({
      flex: 1,
      padding: '12px',
      borderRadius: '8px',
      border: 'none',
      backgroundColor: active ? '#1890ff' : '#f0f0f0',
      color: active ? 'white' : '#666',
      fontSize: '14px',
      fontWeight: '500' as const,
      cursor: 'pointer',
    }),
    statusRow: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      marginBottom: '12px',
    },
    statusIndicator: {
      display: 'flex',
      alignItems: 'center',
    },
    statusDot: {
      width: '12px',
      height: '12px',
      borderRadius: '6px',
      backgroundColor: isConnected ? '#52c41a' : '#d9d9d9',
      marginRight: '8px',
    },
    statusText: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: isConnected ? '#52c41a' : '#666',
    },
    costInfo: {
      textAlign: 'right' as const,
    },
    duration: {
      fontSize: '20px',
      fontWeight: '600' as const,
      color: '#1890ff',
      textAlign: 'center' as const,
      marginBottom: '8px',
    },
    currentCost: {
      fontSize: '16px',
      fontWeight: '500' as const,
      color: '#fa8c16',
      textAlign: 'center' as const,
    },
    billingInfo: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      marginBottom: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    billingTitle: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '12px',
    },
    translationTypeSelector: {
      display: 'flex',
      flexDirection: 'column' as const,
      gap: '8px',
      marginBottom: '16px',
    },
    translationTypeButton: (active: boolean) => ({
      padding: '12px',
      borderRadius: '8px',
      border: active ? '2px solid #1890ff' : '1px solid #d9d9d9',
      backgroundColor: active ? '#e6f7ff' : 'white',
      color: active ? '#1890ff' : '#666',
      fontSize: '14px',
      cursor: 'pointer',
      textAlign: 'left' as const,
    }),
    rateInfo: {
      fontSize: '14px',
      color: '#666',
      marginBottom: '8px',
    },
    interpreterSelector: {
      marginTop: '12px',
    },
    interpreterItem: (selected: boolean) => ({
      display: 'flex',
      alignItems: 'center',
      padding: '12px',
      borderRadius: '8px',
      border: selected ? '2px solid #1890ff' : '1px solid #d9d9d9',
      backgroundColor: selected ? '#e6f7ff' : 'white',
      marginBottom: '8px',
      cursor: 'pointer',
    }),
    interpreterInfo: {
      marginLeft: '12px',
      flex: 1,
    },
    interpreterName: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#333',
    },
    interpreterDetails: {
      fontSize: '12px',
      color: '#666',
    },
    interpreterRate: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#fa8c16',
    },
    languageSelector: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      marginBottom: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    languageRow: {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'space-between',
      marginBottom: '12px',
    },
    languageSelect: {
      flex: 1,
      padding: '12px',
      borderRadius: '8px',
      border: '1px solid #d9d9d9',
      backgroundColor: 'white',
      fontSize: '14px',
    },
    swapButton: {
      margin: '0 12px',
      padding: '8px',
      borderRadius: '20px',
      border: 'none',
      backgroundColor: '#f0f8ff',
      cursor: 'pointer',
      fontSize: '16px',
    },
    controlButtons: {
      display: 'flex',
      justifyContent: 'center',
      gap: '20px',
      marginBottom: '24px',
    },
    controlButton: {
      width: '80px',
      height: '80px',
      borderRadius: '40px',
      border: 'none',
      cursor: 'pointer',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      fontSize: '32px',
      boxShadow: '0 4px 12px rgba(0, 0, 0, 0.15)',
      transition: 'transform 0.2s ease',
    },
    connectButton: {
      backgroundColor: isConnected ? '#ff4d4f' : '#52c41a',
    },
    translationContainer: {
      flex: 1,
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    translationTitle: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '16px',
    },
    translationItem: {
      marginBottom: '16px',
      padding: '12px',
      borderRadius: '8px',
      backgroundColor: '#f8f9fa',
    },
    translationTime: {
      fontSize: '12px',
      color: '#999',
      marginBottom: '4px',
    },
    translationText: {
      fontSize: '14px',
      lineHeight: '1.4',
      marginBottom: '4px',
    },
    originalText: {
      color: '#333',
      fontWeight: '500' as const,
    },
    translatedText: {
      color: '#1890ff',
    },
    speakerTag: {
      fontSize: '12px',
      color: '#666',
      fontStyle: 'italic' as const,
    },
    warningModal: {
      position: 'fixed' as const,
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
      backgroundColor: 'rgba(0, 0, 0, 0.5)',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      zIndex: 1000,
    },
    warningContent: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '24px',
      margin: '20px',
      textAlign: 'center' as const,
    },
    warningTitle: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#fa8c16',
      marginBottom: '12px',
    },
    warningText: {
      fontSize: '14px',
      color: '#666',
      marginBottom: '20px',
    },
    warningButtons: {
      display: 'flex',
      gap: '12px',
      justifyContent: 'center',
    },
    warningButton: (primary: boolean) => ({
      padding: '8px 16px',
      borderRadius: '6px',
      border: 'none',
      backgroundColor: primary ? '#1890ff' : '#f0f0f0',
      color: primary ? 'white' : '#666',
      fontSize: '14px',
      cursor: 'pointer',
    }),
  };

  return (
    <div style={styles.container}>
      {/* 通话类型选择 */}
      <div style={styles.header}>
        <div style={styles.callTypeSelector}>
          <button
            style={styles.callTypeButton(callType === CallType.VOICE)}
            onClick={() => handleCallTypeChange(CallType.VOICE)}
            disabled={isConnected}
          >
            📞 语音通话
          </button>
          <button
            style={styles.callTypeButton(callType === CallType.VIDEO)}
            onClick={() => handleCallTypeChange(CallType.VIDEO)}
            disabled={isConnected}
          >
            📹 视频通话
          </button>
        </div>

        <div style={styles.statusRow}>
          <div style={styles.statusIndicator}>
            <div style={styles.statusDot}></div>
            <span style={styles.statusText}>
              {isConnected ? '通话中' : '未连接'}
            </span>
          </div>
          <div style={styles.costInfo}>
            <div style={styles.duration}>{formatDuration(callDuration)}</div>
            <div style={styles.currentCost}>¥{formatCost(currentCost)}</div>
          </div>
        </div>
      </div>

      {/* 计费信息 */}
      <div style={styles.billingInfo}>
        <div style={styles.billingTitle}>翻译服务选择</div>
        
        <div style={styles.translationTypeSelector}>
          {callType === CallType.VOICE && (
            <button
              style={styles.translationTypeButton(translationType === TranslationType.TEXT)}
              onClick={() => handleTranslationTypeChange(TranslationType.TEXT)}
              disabled={isConnected}
            >
              <div>💬 实时文字翻译</div>
              <div style={styles.rateInfo}>
                {billingRule && `¥${formatCost(billingRule.pricePerMinute)}/分钟`}
              </div>
            </button>
          )}
          
          {callType === CallType.VIDEO && (
            <>
              <button
                style={styles.translationTypeButton(translationType === TranslationType.SIGN_LANGUAGE)}
                onClick={() => handleTranslationTypeChange(TranslationType.SIGN_LANGUAGE)}
                disabled={isConnected}
              >
                <div>👋 虚拟人手语翻译</div>
                <div style={styles.rateInfo}>
                  {billingRule && `¥${formatCost(billingRule.pricePerMinute)}/分钟`}
                </div>
              </button>
              
              <button
                style={styles.translationTypeButton(translationType === TranslationType.HUMAN_INTERPRETER)}
                onClick={() => handleTranslationTypeChange(TranslationType.HUMAN_INTERPRETER)}
                disabled={isConnected}
              >
                <div>👨‍💼 真人翻译员</div>
                <div style={styles.rateInfo}>
                  {billingRule && `¥${formatCost(billingRule.pricePerMinute)}/分钟 + 翻译员费用`}
                </div>
              </button>
            </>
          )}
        </div>

        {/* 翻译员选择 */}
        {translationType === TranslationType.HUMAN_INTERPRETER && (
          <div style={styles.interpreterSelector}>
            <div style={styles.billingTitle}>选择翻译员</div>
            {availableInterpreters.map((interpreter) => (
              <div
                key={interpreter.id}
                style={styles.interpreterItem(selectedInterpreter?.id === interpreter.id)}
                onClick={() => handleInterpreterSelect(interpreter)}
              >
                <div>{interpreter.avatar}</div>
                <div style={styles.interpreterInfo}>
                  <div style={styles.interpreterName}>{interpreter.name}</div>
                  <div style={styles.interpreterDetails}>
                    {interpreter.languages.join(', ')} | ⭐ {interpreter.rating}
                  </div>
                </div>
                <div style={styles.interpreterRate}>
                  ¥{formatCost(interpreter.pricePerMinute)}/分钟
                </div>
              </div>
            ))}
          </div>
        )}
      </div>

      {/* 语言选择器 */}
      <div style={styles.languageSelector}>
        <div style={styles.languageRow}>
          <select
            style={styles.languageSelect}
            value={selectedLanguages.from}
            onChange={(e) => setSelectedLanguages({...selectedLanguages, from: e.target.value})}
            disabled={isConnected}
          >
            {languages.map(lang => (
              <option key={lang.code} value={lang.code}>
                {lang.flag} {lang.name}
              </option>
            ))}
          </select>
          
          <button style={styles.swapButton} onClick={swapLanguages} disabled={isConnected}>
            🔄
          </button>
          
          <select
            style={styles.languageSelect}
            value={selectedLanguages.to}
            onChange={(e) => setSelectedLanguages({...selectedLanguages, to: e.target.value})}
            disabled={isConnected}
          >
            {languages.map(lang => (
              <option key={lang.code} value={lang.code}>
                {lang.flag} {lang.name}
              </option>
            ))}
          </select>
        </div>
      </div>

      {/* 控制按钮 */}
      <div style={styles.controlButtons}>
        <button
          style={{...styles.controlButton, ...styles.connectButton}}
          onClick={isConnected ? handleDisconnect : handleConnect}
        >
          {isConnected ? '📞' : (callType === CallType.VIDEO ? '📹' : '📱')}
        </button>
      </div>

      {/* 翻译历史 */}
      <div style={styles.translationContainer}>
        <h3 style={styles.translationTitle}>
          {translationType === TranslationType.TEXT ? '实时翻译' : 
           translationType === TranslationType.SIGN_LANGUAGE ? '手语翻译' : '翻译员服务'}
        </h3>
        {translationHistory.map((item, index) => (
          <div key={index} style={styles.translationItem}>
            <div style={styles.translationTime}>{item.time}</div>
            <div style={{...styles.translationText, ...styles.originalText}}>
              {item.original}
            </div>
            <div style={{...styles.translationText, ...styles.translatedText}}>
              {item.translated}
            </div>
            <div style={styles.speakerTag}>
              {item.speaker === 'you' ? '您' : '对方'}
            </div>
          </div>
        ))}
      </div>

      {/* 低余额警告 */}
      {showLowBalanceWarning && (
        <div style={styles.warningModal}>
          <div style={styles.warningContent}>
            <div style={styles.warningTitle}>⚠️ 余额不足警告</div>
            <div style={styles.warningText}>
              您的账户余额即将不足，可能无法维持通话超过5分钟。
              建议立即充值以避免通话中断。
            </div>
            <div style={styles.warningButtons}>
              <button
                style={styles.warningButton(false)}
                onClick={() => setShowLowBalanceWarning(false)}
              >
                继续通话
              </button>
              <button
                style={styles.warningButton(true)}
                onClick={() => {
                  setShowLowBalanceWarning(false);
                  navigate('/mobile/recharge');
                }}
              >
                立即充值
              </button>
            </div>
          </div>
        </div>
      )}
    </div>
  );
};

export default MobileCall; 