import React, { useState, useEffect, useRef } from 'react';
import {
  View,
  Text,
  StyleSheet,
  TouchableOpacity,
  Alert,
  SafeAreaView,
  Dimensions,
  StatusBar,
} from 'react-native';
import { BillingService } from '../services/billingService';
import { CallType, TranslationType, UserAccount, UserType } from '../types/billing';

// 模拟语言数据
const mockLanguages = [
  { code: 'zh', name: '中文', nativeName: '中文' },
  { code: 'en', name: 'English', nativeName: 'English' },
  { code: 'ja', name: 'Japanese', nativeName: '日本語' },
  { code: 'ko', name: 'Korean', nativeName: '한국어' },
];

interface Language {
  code: string;
  name: string;
  nativeName: string;
}

interface CallSession {
  id: string;
  userId: string;
  mode: string;
  sourceLanguage: string;
  targetLanguage: string;
  status: 'active' | 'completed' | 'failed';
  duration: number;
  cost: number;
  twilioRoomId: string;
  createdAt: string;
}

interface CallScreenProps {
  route?: {
    params?: {
      mode?: string;
      sourceLanguage?: string;
      targetLanguage?: string;
    };
  };
  navigation?: {
    goBack: () => void;
  };
}

const CallScreen: React.FC<CallScreenProps> = ({ route, navigation }) => {
  const [isConnected, setIsConnected] = useState(false);
  const [isConnecting, setIsConnecting] = useState(true);
  const [isMuted, setIsMuted] = useState(false);
  const [isVideoEnabled, setIsVideoEnabled] = useState(true);
  const [callDuration, setCallDuration] = useState(0);
  const [currentCall, setCurrentCall] = useState<CallSession | null>(null);
  
  // 计费相关状态
  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [currentCost, setCurrentCost] = useState(0);
  const [billingService] = useState(() => BillingService.getInstance());
  const [lastBillingMinute, setLastBillingMinute] = useState(0);
  
  const callTimer = useRef<NodeJS.Timeout | null>(null);
  const startTime = useRef<Date | null>(null);
  const billingInterval = useRef<NodeJS.Timeout | null>(null);

  // 从路由参数获取通话配置
  const callMode = route?.params?.mode || 'ai';
  const sourceLanguage = route?.params?.sourceLanguage || 'zh';
  const targetLanguage = route?.params?.targetLanguage || 'en';

  // 根据模式确定通话和翻译类型
  const getCallType = (mode: string): CallType => {
    return mode === 'video' || mode === 'sign' ? CallType.VIDEO : CallType.VOICE;
  };

  const getTranslationType = (mode: string): TranslationType => {
    switch (mode) {
      case 'sign':
        return TranslationType.SIGN_LANGUAGE;
      case 'human':
        return TranslationType.HUMAN_INTERPRETER;
      default:
        return TranslationType.TEXT;
    }
  };

  const callType = getCallType(callMode);
  const translationType = getTranslationType(callMode);

  // 获取语言信息
  const getLanguageInfo = (code: string): Language | undefined => {
    return mockLanguages.find(lang => lang.code === code);
  };

  const sourceLang = getLanguageInfo(sourceLanguage);
  const targetLang = getLanguageInfo(targetLanguage);

  // 初始化用户账户
  useEffect(() => {
    const initUserAccount = () => {
      const mockAccount: UserAccount = {
        id: 'user-123',
        userType: UserType.INDIVIDUAL,
        balance: 10000, // 100元
      };
      billingService.setUserAccount(mockAccount);
      setUserAccount(mockAccount);
    };

    initUserAccount();
  }, [billingService]);

  useEffect(() => {
    // 模拟连接过程
    connectToCall();
    
    return () => {
      if (callTimer.current) {
        clearInterval(callTimer.current);
      }
      if (billingInterval.current) {
        clearInterval(billingInterval.current);
      }
    };
  }, []);

  // 检查余额
  const checkBalance = (): boolean => {
    if (!userAccount) return false;
    
    const balanceCheck = billingService.checkBalance(callType, translationType, 1);
    if (!balanceCheck.sufficient) {
      Alert.alert(
        '余额不足',
        `需要至少 ¥${(balanceCheck.requiredAmount / 100).toFixed(2)} 才能开始通话`,
        [{ text: '确定', onPress: () => navigation?.goBack() }]
      );
      return false;
    }
    
    const shouldWarn = billingService.shouldShowLowBalanceWarning(callType, translationType);
    if (shouldWarn) {
      Alert.alert('提醒', '账户余额较低，请及时充值');
    }
    
    return true;
  };

  // 开始计费
  const startBilling = () => {
    startTime.current = new Date();
    
    // 每分钟进行计费
    billingInterval.current = setInterval(() => {
      if (startTime.current) {
        const currentMinute = Math.floor((Date.now() - startTime.current.getTime()) / 60000);
        if (currentMinute > lastBillingMinute) {
          performBilling(currentMinute);
          setLastBillingMinute(currentMinute);
        }
      }
    }, 60000);
  };

  // 执行计费
  const performBilling = (minute: number) => {
    if (!userAccount) return;

    try {
      const cost = billingService.calculateCallCost(callType, translationType, 1);
      const newTotalCost = currentCost + cost;
      
      // 检查余额是否足够继续通话
      const balanceCheck = billingService.checkBalance(callType, translationType, 1);
      if (!balanceCheck.sufficient) {
        Alert.alert('余额不足', '通话即将结束', [
          { text: '确定', onPress: () => endCall() }
        ]);
        return;
      }

      // 扣费
      const deductSuccess = billingService.deductBalance(cost);
      if (deductSuccess) {
        setCurrentCost(newTotalCost);
        const updatedAccount = billingService.getUserAccount();
        setUserAccount(updatedAccount);
        
        const shouldWarn = billingService.shouldShowLowBalanceWarning(callType, translationType);
        if (shouldWarn) {
          Alert.alert('提醒', '账户余额较低，请及时充值');
        }
      } else {
        Alert.alert('扣费失败', '通话即将结束', [
          { text: '确定', onPress: () => endCall() }
        ]);
      }
    } catch (error) {
      console.error('计费失败:', error);
      Alert.alert('计费系统异常', '通话即将结束', [
        { text: '确定', onPress: () => endCall() }
      ]);
    }
  };

  const connectToCall = async () => {
    try {
      setIsConnecting(true);
      
      // 检查余额
      if (!checkBalance()) {
        return;
      }
      
      // 模拟获取Twilio token和连接过程
      // const tokenResponse = await apiService.getTwilioToken(callMode);
      // const callResponse = await apiService.startCall({
      //   mode: callMode,
      //   sourceLanguage,
      //   targetLanguage,
      // });
      
      // 模拟连接延迟
      setTimeout(() => {
        setIsConnecting(false);
        setIsConnected(true);
        startCallTimer();
        startBilling(); // 开始计费
        
        // 创建模拟通话会话
        const mockCall: CallSession = {
          id: `call-${Date.now()}`,
          userId: 'user-123',
          mode: callMode,
          sourceLanguage,
          targetLanguage,
          status: 'active',
          duration: 0,
          cost: 0,
          twilioRoomId: `room-${Date.now()}`,
          createdAt: new Date().toISOString(),
        };
        setCurrentCall(mockCall);
      }, 2000);
      
    } catch (error) {
      console.error('Failed to connect to call:', error);
      Alert.alert('连接失败', '无法建立通话连接，请重试。');
      navigation?.goBack();
    }
  };

  const startCallTimer = () => {
    startTime.current = new Date();
    callTimer.current = setInterval(() => {
      if (startTime.current) {
        const elapsed = Math.floor((Date.now() - startTime.current.getTime()) / 1000);
        setCallDuration(elapsed);
      }
    }, 1000);
  };

  const formatDuration = (seconds: number): string => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };

  const formatCost = (cents: number): string => {
    return (cents / 100).toFixed(2);
  };

  const handleEndCall = () => {
    Alert.alert(
      '结束通话',
      `通话时长: ${formatDuration(callDuration)}\n费用: ¥${formatCost(currentCost)}\n确定要结束当前通话吗？`,
      [
        { text: '取消', style: 'cancel' },
        { 
          text: '结束', 
          style: 'destructive',
          onPress: () => {
            endCall();
          }
        },
      ]
    );
  };

  const endCall = async () => {
    try {
      if (callTimer.current) {
        clearInterval(callTimer.current);
      }
      if (billingInterval.current) {
        clearInterval(billingInterval.current);
      }
      
      // 在实际应用中调用API结束通话
      // if (currentCall) {
      //   await apiService.endCall(currentCall.id, callDuration);
      // }
      
      setIsConnected(false);
      navigation?.goBack();
    } catch (error) {
      console.error('Failed to end call:', error);
      navigation?.goBack();
    }
  };

  const toggleMute = () => {
    setIsMuted(!isMuted);
    // 在实际应用中控制音频
    // twilioRoom?.localParticipant?.audioTracks?.forEach(track => {
    //   track.enable(!isMuted);
    // });
  };

  const toggleVideo = () => {
    if (callMode === 'video' || callMode === 'sign') {
      setIsVideoEnabled(!isVideoEnabled);
      // 在实际应用中控制视频
      // twilioRoom?.localParticipant?.videoTracks?.forEach(track => {
      //   track.enable(!isVideoEnabled);
      // });
    }
  };

  const getModeTitle = (mode: string): string => {
    const modeMap: { [key: string]: string } = {
      ai: 'AI翻译通话',
      human: '人工翻译通话',
      video: '视频翻译通话',
      sign: '手语翻译通话',
    };
    return modeMap[mode] || '通话中';
  };

  const getModeIcon = (mode: string): string => {
    const iconMap: { [key: string]: string } = {
      ai: '🤖',
      human: '👥',
      video: '📹',
      sign: '🤟',
    };
    return iconMap[mode] || '📞';
  };

  if (isConnecting) {
    return (
      <SafeAreaView style={styles.container}>
        <StatusBar barStyle="light-content" backgroundColor="#1a1a1a" />
        <View style={styles.connectingContainer}>
          <Text style={styles.connectingText}>正在连接...</Text>
          <Text style={styles.modeText}>{getModeTitle(callMode)}</Text>
          <Text style={styles.languageText}>
            {sourceLang?.nativeName} → {targetLang?.nativeName}
          </Text>
          {userAccount && (
            <View style={styles.balanceInfo}>
              <Text style={styles.balanceText}>
                账户余额: ¥{formatCost(userAccount.balance)}
              </Text>
              <Text style={styles.rateText}>
                费率: ¥{formatCost(billingService.calculateCallCost(callType, translationType, 1))}/分钟
              </Text>
            </View>
          )}
        </View>
      </SafeAreaView>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <StatusBar barStyle="light-content" backgroundColor="#1a1a1a" />
      
      {/* 顶部信息栏 */}
      <View style={styles.topBar}>
        <View style={styles.callInfo}>
          <Text style={styles.modeIcon}>{getModeIcon(callMode)}</Text>
          <View style={styles.callDetails}>
            <Text style={styles.callTitle}>{getModeTitle(callMode)}</Text>
            <Text style={styles.languagesText}>
              {sourceLang?.nativeName} → {targetLang?.nativeName}
            </Text>
          </View>
        </View>
        <View style={styles.callStats}>
          <Text style={styles.duration}>{formatDuration(callDuration)}</Text>
          <Text style={styles.cost}>¥{formatCost(currentCost)}</Text>
          {userAccount && (
            <Text style={styles.balance}>
              余额: ¥{formatCost(userAccount.balance)}
            </Text>
          )}
        </View>
      </View>

      {/* 视频区域 */}
      <View style={styles.videoContainer}>
        {(callMode === 'video' || callMode === 'sign') ? (
          <View style={styles.videoArea}>
            <View style={styles.remoteVideo}>
              <Text style={styles.videoPlaceholder}>
                {callMode === 'sign' ? '手语翻译员' : '翻译员视频'}
              </Text>
            </View>
            <View style={styles.localVideo}>
              <Text style={styles.videoPlaceholder}>您的视频</Text>
            </View>
          </View>
        ) : (
          <View style={styles.audioOnlyArea}>
            <Text style={styles.audioIcon}>
              {callMode === 'ai' ? '🤖' : '👥'}
            </Text>
            <Text style={styles.audioTitle}>
              {callMode === 'ai' ? 'AI翻译中...' : '人工翻译中...'}
            </Text>
            <View style={styles.waveform}>
              {[1, 2, 3, 4, 5].map((i) => (
                <View key={i} style={[styles.waveBar, { height: Math.random() * 40 + 10 }]} />
              ))}
            </View>
          </View>
        )}
      </View>

      {/* 控制按钮 */}
      <View style={styles.controlsContainer}>
        <TouchableOpacity
          style={[styles.controlButton, isMuted && styles.mutedButton]}
          onPress={toggleMute}
        >
          <Text style={styles.controlButtonText}>
            {isMuted ? '🔇' : '🎤'}
          </Text>
        </TouchableOpacity>

        <TouchableOpacity
          style={styles.endCallButton}
          onPress={handleEndCall}
        >
          <Text style={styles.endCallButtonText}>📞</Text>
        </TouchableOpacity>

        {(callMode === 'video' || callMode === 'sign') && (
          <TouchableOpacity
            style={[styles.controlButton, !isVideoEnabled && styles.mutedButton]}
            onPress={toggleVideo}
          >
            <Text style={styles.controlButtonText}>
              {isVideoEnabled ? '📹' : '📷'}
            </Text>
          </TouchableOpacity>
        )}
      </View>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#1a1a1a',
  },
  connectingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    padding: 20,
  },
  connectingText: {
    fontSize: 24,
    color: '#fff',
    marginBottom: 20,
  },
  modeText: {
    fontSize: 18,
    color: '#ccc',
    marginBottom: 10,
  },
  languageText: {
    fontSize: 16,
    color: '#999',
    marginBottom: 20,
  },
  balanceInfo: {
    backgroundColor: 'rgba(255, 255, 255, 0.1)',
    padding: 16,
    borderRadius: 12,
    marginBottom: 32,
  },
  balanceText: {
    fontSize: 18,
    color: '#fff',
    textAlign: 'center',
  },
  rateText: {
    fontSize: 16,
    color: '#ccc',
    textAlign: 'center',
  },
  topBar: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 20,
    backgroundColor: 'rgba(255, 255, 255, 0.1)',
  },
  callInfo: {
    flexDirection: 'row',
    alignItems: 'center',
    flex: 1,
  },
  modeIcon: {
    fontSize: 24,
    marginRight: 12,
  },
  callDetails: {
    flex: 1,
  },
  callTitle: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#fff',
  },
  languagesText: {
    fontSize: 14,
    color: '#ccc',
  },
  callStats: {
    alignItems: 'flex-end',
  },
  duration: {
    fontSize: 24,
    fontWeight: 'bold',
    color: '#fff',
  },
  cost: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#4CAF50',
  },
  balance: {
    fontSize: 14,
    color: '#ccc',
  },
  videoContainer: {
    flex: 1,
    padding: 20,
  },
  videoArea: {
    flex: 1,
    position: 'relative',
  },
  remoteVideo: {
    flex: 1,
    backgroundColor: '#333',
    borderRadius: 12,
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom: 20,
  },
  localVideo: {
    position: 'absolute',
    top: 20,
    right: 20,
    width: 120,
    height: 160,
    backgroundColor: '#555',
    borderRadius: 8,
    justifyContent: 'center',
    alignItems: 'center',
  },
  videoPlaceholder: {
    color: '#fff',
    fontSize: 16,
  },
  audioOnlyArea: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  audioIcon: {
    fontSize: 80,
    marginBottom: 20,
  },
  audioTitle: {
    fontSize: 24,
    color: '#fff',
    marginBottom: 40,
  },
  waveform: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    gap: 4,
  },
  waveBar: {
    width: 4,
    backgroundColor: '#4CAF50',
    borderRadius: 2,
  },
  controlsContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    paddingHorizontal: 40,
    paddingBottom: 40,
    gap: 40,
  },
  controlButton: {
    width: 60,
    height: 60,
    borderRadius: 30,
    backgroundColor: 'rgba(255, 255, 255, 0.2)',
    justifyContent: 'center',
    alignItems: 'center',
  },
  mutedButton: {
    backgroundColor: '#F44336',
  },
  controlButtonText: {
    fontSize: 24,
  },
  endCallButton: {
    width: 80,
    height: 80,
    borderRadius: 40,
    backgroundColor: '#F44336',
    justifyContent: 'center',
    alignItems: 'center',
  },
  endCallButtonText: {
    fontSize: 32,
    transform: [{ rotate: '135deg' }],
  },
});

export default CallScreen; 
